# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ApiKeyCreateResponse(Model):
    """ApiKeyCreateResponse.

    :param api_key: The API key. This value cannot be retrieved again after it
     is created.
    :type api_key: str
    :param api_key_id: The identifier of the API key
    :type api_key_id: int
    :param api_key_name: The name of the API key
    :type api_key_name: str
    :param api_key_description: A description of the API key
    :type api_key_description: str
    :param created_by:
    :type created_by: ~energycap.sdk.models.UserChild
    """

    _attribute_map = {
        'api_key': {'key': 'apiKey', 'type': 'str'},
        'api_key_id': {'key': 'apiKeyId', 'type': 'int'},
        'api_key_name': {'key': 'apiKeyName', 'type': 'str'},
        'api_key_description': {'key': 'apiKeyDescription', 'type': 'str'},
        'created_by': {'key': 'createdBy', 'type': 'UserChild'},
    }

    def __init__(self, api_key=None, api_key_id=None, api_key_name=None, api_key_description=None, created_by=None):
        super(ApiKeyCreateResponse, self).__init__()
        self.api_key = api_key
        self.api_key_id = api_key_id
        self.api_key_name = api_key_name
        self.api_key_description = api_key_description
        self.created_by = created_by



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceDigestEnergyUseIntensityEuiCommodity(Model):
    """PlaceDigestEnergyUseIntensityEuiCommodity.

    :param commodity_id: The commodity identifier
    :type commodity_id: int
    :param commodity_code: The commodity code
    :type commodity_code: str
    :param commodity_info: The commodity info
    :type commodity_info: str
    :param use: The use for the commodity
    :type use: float
    :param use_percent: The percent of the building's energy used by the
     commodity
    :type use_percent: float
    """

    _attribute_map = {
        'commodity_id': {'key': 'commodityId', 'type': 'int'},
        'commodity_code': {'key': 'commodityCode', 'type': 'str'},
        'commodity_info': {'key': 'commodityInfo', 'type': 'str'},
        'use': {'key': 'use', 'type': 'float'},
        'use_percent': {'key': 'usePercent', 'type': 'float'},
    }

    def __init__(self, commodity_id=None, commodity_code=None, commodity_info=None, use=None, use_percent=None):
        super(PlaceDigestEnergyUseIntensityEuiCommodity, self).__init__()
        self.commodity_id = commodity_id
        self.commodity_code = commodity_code
        self.commodity_info = commodity_info
        self.use = use
        self.use_percent = use_percent



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CostCenterDigestActualYearlyResponseResults(Model):
    """CostCenterDigestActualYearlyResponseResults.

    :param year: Year
    :type year: str
    :param total_cost: Total Cost
    :type total_cost: float
    :param global_use: Global Use
    :type global_use: float
    :param global_use_unit_cost: Global Use Unit Cost
    :type global_use_unit_cost: float
    """

    _attribute_map = {
        'year': {'key': 'year', 'type': 'str'},
        'total_cost': {'key': 'totalCost', 'type': 'float'},
        'global_use': {'key': 'globalUse', 'type': 'float'},
        'global_use_unit_cost': {'key': 'globalUseUnitCost', 'type': 'float'},
    }

    def __init__(self, year=None, total_cost=None, global_use=None, global_use_unit_cost=None):
        super(CostCenterDigestActualYearlyResponseResults, self).__init__()
        self.year = year
        self.total_cost = total_cost
        self.global_use = global_use
        self.global_use_unit_cost = global_use_unit_cost



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from .account_type_child import AccountTypeChild
from .cost_center_child import CostCenterChild
from .vendor_child import VendorChild
from .contact_child import ContactChild
from .customer_child import CustomerChild
from .address_child import AddressChild
from .general_ledger_child import GeneralLedgerChild
from .place_type_response import PlaceTypeResponse
from .place_child import PlaceChild
from .commodity_child import CommodityChild
from .vendor_type_child import VendorTypeChild
from .account_meter_child_with_serial_number import AccountMeterChildWithSerialNumber
from .user_child import UserChild
from .unit_child import UnitChild
from .account_response import AccountResponse
from .account_edit import AccountEdit
from .account_create import AccountCreate
from .meter_type_child import MeterTypeChild
from .meter_child_search import MeterChildSearch
from .search_account_meter_bill_entry import SearchAccountMeterBillEntry
from .udf_value import UDFValue
from .data_type_response import DataTypeResponse
from .udf_select_value_entity_response import UDFSelectValueEntityResponse
from .udf_field_child import UDFFieldChild
from .account_udf_response import AccountUDFResponse
from .account_meter_child import AccountMeterChild
from .account_rate_response import AccountRateResponse
from .account_template_response import AccountTemplateResponse
from .account_alert_response import AccountAlertResponse
from .account_alert_request import AccountAlertRequest
from .single_value import SingleValue
from .update_result import UpdateResult
from .account_digest_actual_yearly_response_results import AccountDigestActualYearlyResponseResults
from .account_digest_actual_yearly_response_commodity_results import AccountDigestActualYearlyResponseCommodityResults
from .account_digest_actual_yearly_response_commodity_data import AccountDigestActualYearlyResponseCommodityData
from .account_digest_actual_yearly_response import AccountDigestActualYearlyResponse
from .account_digest_actual_monthly_response_commodity_results import AccountDigestActualMonthlyResponseCommodityResults
from .account_digest_actual_monthly_response_commodity_data import AccountDigestActualMonthlyResponseCommodityData
from .account_digest_actual_monthly_response_results import AccountDigestActualMonthlyResponseResults
from .account_digest_actual_monthly_response import AccountDigestActualMonthlyResponse
from .account_meter_request import AccountMeterRequest
from .account_child import AccountChild
from .meter_child import MeterChild
from .template_child import TemplateChild
from .form_template_child import FormTemplateChild
from .rate_child import RateChild
from .account_rate_child import AccountRateChild
from .account_meter_response import AccountMeterResponse
from .account_meter_edit import AccountMeterEdit
from .account_rate_request import AccountRateRequest
from .account_meter_rate_response import AccountMeterRateResponse
from .form_template_request import FormTemplateRequest
from .form_template_response import FormTemplateResponse
from .activity import Activity
from .admin_settings_response import AdminSettingsResponse
from .admin_settings_request import AdminSettingsRequest
from .account_period_response import AccountPeriodResponse
from .accounting_settings_response import AccountingSettingsResponse
from .account_period_request import AccountPeriodRequest
from .accounting_settings_request import AccountingSettingsRequest
from .time_zone_response import TimeZoneResponse
from .system_user_role_child import SystemUserRoleChild
from .system_settings_response import SystemSettingsResponse
from .system_settings_request import SystemSettingsRequest
from .api_key_request import ApiKeyRequest
from .api_key_create_response import ApiKeyCreateResponse
from .api_key_response import ApiKeyResponse
from .bill_contains_line_item_descriptions_setting import BillContainsLineItemDescriptionsSetting
from .bill_contains_line_item_types_setting import BillContainsLineItemTypesSetting
from .total_bill_cost_does_not_match_line_item_types_setting import TotalBillCostDoesNotMatchLineItemTypesSetting
from .audit_setting import AuditSetting
from .bill_significantly_shorter_or_longer_than_previous_setting import BillSignificantlyShorterOrLongerThanPreviousSetting
from .too_many_consecutive_estimated_bills_setting import TooManyConsecutiveEstimatedBillsSetting
from .due_date_too_long_after_bill_end_setting import DueDateTooLongAfterBillEndSetting
from .statement_date_too_long_after_bill_end_setting import StatementDateTooLongAfterBillEndSetting
from .audit_settings import AuditSettings
from .login_request import LoginRequest
from .api_user import ApiUser
from .login_response import LoginResponse
from .batch_create import BatchCreate
from .batch_response import BatchResponse
from .batch_edit import BatchEdit
from .batch_child import BatchChild
from .observation_method_child import ObservationMethodChild
from .bill_response import BillResponse
from .bill_meter_body_line_create import BillMeterBodyLineCreate
from .bill_meter_create import BillMeterCreate
from .bill_account_body_line_create import BillAccountBodyLineCreate
from .bill_create import BillCreate
from .bill_id_response import BillIdResponse
from .bill_meter_body_line_edit import BillMeterBodyLineEdit
from .bill_meter_edit import BillMeterEdit
from .bill_account_body_line_edit import BillAccountBodyLineEdit
from .bill_edit import BillEdit
from .observation_type_child import ObservationTypeChild
from .bodyline_response import BodylineResponse
from .bill_action_void import BillActionVoid
from .bill_header_update_begin_date_child import BillHeaderUpdateBeginDateChild
from .bill_header_update_end_date_child import BillHeaderUpdateEndDateChild
from .bill_header_update_due_date_child import BillHeaderUpdateDueDateChild
from .bill_header_update_statement_date_child import BillHeaderUpdateStatementDateChild
from .bill_header_update_control_code_child import BillHeaderUpdateControlCodeChild
from .bill_header_update_invoice_number_child import BillHeaderUpdateInvoiceNumberChild
from .bill_header_update_account_period_child import BillHeaderUpdateAccountPeriodChild
from .bill_header_update_billing_period_child import BillHeaderUpdateBillingPeriodChild
from .bill_header_update_estimated_child import BillHeaderUpdateEstimatedChild
from .bill_header_update import BillHeaderUpdate
from .bill_action_header_update import BillActionHeaderUpdate
from .bill_header_update_response_child import BillHeaderUpdateResponseChild
from .bill_header_update_response import BillHeaderUpdateResponse
from .bill_action_approve import BillActionApprove
from .bill_action_export_hold import BillActionExportHold
from .bill_action_delete import BillActionDelete
from .bill_delete_action_result import BillDeleteActionResult
from .list_ids import ListIds
from .destination_account_meter_child import DestinationAccountMeterChild
from .destination_account_response import DestinationAccountResponse
from .move_bills_destination import MoveBillsDestination
from .bill_action_move import BillActionMove
from .bill_account_meter_response import BillAccountMeterResponse
from .bill_header_child import BillHeaderChild
from .bill_entry_body_line_with_noun_child import BillEntryBodyLineWithNounChild
from .bill_entry_body_line_child import BillEntryBodyLineChild
from .bill_entry_observation_type_child import BillEntryObservationTypeChild
from .bill_entry_body_line import BillEntryBodyLine
from .bill_entry_meter_child import BillEntryMeterChild
from .bill_entry_response import BillEntryResponse
from .bill_account_meter_child import BillAccountMeterChild
from .bill_history_response import BillHistoryResponse
from .bill_export import BillExport
from .bill_unexport import BillUnexport
from .bill_action_split import BillActionSplit
from .chargeback_workflow_base import ChargebackWorkflowBase
from .chargeback_workflow_step_child import ChargebackWorkflowStepChild
from .chargeback_task_response import ChargebackTaskResponse
from .account_child_with_type import AccountChildWithType
from .distribution_version_response import DistributionVersionResponse
from .distribution_version_manage import DistributionVersionManage
from .bill_split_place_size_child import BillSplitPlaceSizeChild
from .place_child_with_floor_area import PlaceChildWithFloorArea
from .fixed_percentage_response import FixedPercentageResponse
from .floor_area_split_response import FloorAreaSplitResponse
from .meter_group_child import MeterGroupChild
from .dynamic_percentage_bill_split_response import DynamicPercentageBillSplitResponse
from .bill_split_details_response import BillSplitDetailsResponse
from .fixed_percentage import FixedPercentage
from .floor_area_split import FloorAreaSplit
from .dynamic_percentage_bill_split import DynamicPercentageBillSplit
from .bill_split_details_request import BillSplitDetailsRequest
from .chargeback_task_version_response import ChargebackTaskVersionResponse
from .bill_split_parent_details_response import BillSplitParentDetailsResponse
from .bill_view_address_child import BillViewAddressChild
from .bill_view_vendor_child import BillViewVendorChild
from .bill_view_account_child import BillViewAccountChild
from .bill_view_meter_child import BillViewMeterChild
from .bodyline_child import BodylineChild
from .bill_calendarized_history import BillCalendarizedHistory
from .bill_view_response import BillViewResponse
from .observation_rule import ObservationRule
from .channel_child_with_observation_type import ChannelChildWithObservationType
from .fixed_amount_response import FixedAmountResponse
from .copy_from_meter_response import CopyFromMeterResponse
from .sum_response import SumResponse
from .subtract_response import SubtractResponse
from .calculation_response import CalculationResponse
from .calculated_bill_use_response import CalculatedBillUseResponse
from .rate_child_response import RateChildResponse
from .calculated_bill_cost_response import CalculatedBillCostResponse
from .calculated_bill_demand_response import CalculatedBillDemandResponse
from .generic_bodyline_response import GenericBodylineResponse
from .calculated_bill_details_response import CalculatedBillDetailsResponse
from .fixed_use_request import FixedUseRequest
from .copy_meter_request import CopyMeterRequest
from .sum_request import SumRequest
from .subtract_request import SubtractRequest
from .calculation_request import CalculationRequest
from .calculated_bill_use_request import CalculatedBillUseRequest
from .fixed_unit_cost_request import FixedUnitCostRequest
from .calculated_bill_cost_request import CalculatedBillCostRequest
from .fixed_demand_request import FixedDemandRequest
from .calculated_bill_demand_request import CalculatedBillDemandRequest
from .generic_bodyline_request import GenericBodylineRequest
from .observation_method import ObservationMethod
from .device_channel_child import DeviceChannelChild
from .channel_response import ChannelResponse
from .channel_edit import ChannelEdit
from .channel_create import ChannelCreate
from .quick_filter import QuickFilter
from .chargeback_processor_settings import ChargebackProcessorSettings
from .chargeback_processor_settings_without_filters import ChargebackProcessorSettingsWithoutFilters
from .chargeback_task_request import ChargebackTaskRequest
from .chargeback_workflow_step import ChargebackWorkflowStep
from .chargeback_workflow_response import ChargebackWorkflowResponse
from .chargeback_workflow_step_create import ChargebackWorkflowStepCreate
from .chargeback_workflow_create import ChargebackWorkflowCreate
from .chargeback_workflow_step_edit import ChargebackWorkflowStepEdit
from .chargeback_workflow_edit import ChargebackWorkflowEdit
from .assign_versions_to_step import AssignVersionsToStep
from .billing_period_use_unit_child import BillingPeriodUseUnitChild
from .billing_period_cost_unit_child import BillingPeriodCostUnitChild
from .billing_period_use_cost_child import BillingPeriodUseCostChild
from .billing_period_use_unit_delta_child import BillingPeriodUseUnitDeltaChild
from .billing_period_cost_unit_delta_child import BillingPeriodCostUnitDeltaChild
from .billing_period_use_cost_delta_child import BillingPeriodUseCostDeltaChild
from .chargeback_workflow_digest_split_child import ChargebackWorkflowDigestSplitChild
from .chargeback_workflow_digest_child import ChargebackWorkflowDigestChild
from .chargeback_workflow_digest_response import ChargebackWorkflowDigestResponse
from .commodity import Commodity
from .commodity_digest_actual_yearly_response_results import CommodityDigestActualYearlyResponseResults
from .commodity_digest_actual_yearly_response_commodity_results import CommodityDigestActualYearlyResponseCommodityResults
from .commodity_digest_actual_yearly_response_commodity_data import CommodityDigestActualYearlyResponseCommodityData
from .commodity_digest_actual_yearly_response import CommodityDigestActualYearlyResponse
from .cost_center_account_child import CostCenterAccountChild
from .cost_center_response import CostCenterResponse
from .cost_center_create import CostCenterCreate
from .cost_center_digest_actual_yearly_response_results import CostCenterDigestActualYearlyResponseResults
from .cost_center_digest_actual_yearly_response_commodity_results import CostCenterDigestActualYearlyResponseCommodityResults
from .cost_center_digest_actual_yearly_response_commodity_data import CostCenterDigestActualYearlyResponseCommodityData
from .cost_center_digest_actual_yearly_response import CostCenterDigestActualYearlyResponse
from .cost_center_digest_actual_monthly_response_commodity_results import CostCenterDigestActualMonthlyResponseCommodityResults
from .cost_center_digest_actual_monthly_response_commodity_data import CostCenterDigestActualMonthlyResponseCommodityData
from .cost_center_digest_actual_monthly_response_results import CostCenterDigestActualMonthlyResponseResults
from .cost_center_digest_actual_monthly_response import CostCenterDigestActualMonthlyResponse
from .customer_response import CustomerResponse
from .dashboard_response import DashboardResponse
from .dashboard_create import DashboardCreate
from .dashboard_edit import DashboardEdit
from .dashboard_copy import DashboardCopy
from .filter_response import FilterResponse
from .specific_widget_response import SpecificWidgetResponse
from .filter_edit import FilterEdit
from .widget_create import WidgetCreate
from .widget_edit import WidgetEdit
from .user_group_child import UserGroupChild
from .share_response import ShareResponse
from .share_request import ShareRequest
from .toggle_visible import ToggleVisible
from .energy_savings_unit import EnergySavingsUnit
from .energy_savings_child import EnergySavingsChild
from .cost_savings_unit import CostSavingsUnit
from .cost_savings_child import CostSavingsChild
from .energy_project_place_child import EnergyProjectPlaceChild
from .energy_project_type import EnergyProjectType
from .energy_project_response import EnergyProjectResponse
from .energy_project_edit import EnergyProjectEdit
from .energy_project_create import EnergyProjectCreate
from .energy_project_type_create import EnergyProjectTypeCreate
from .project_manager_response import ProjectManagerResponse
from .energy_star_settings_response import EnergyStarSettingsResponse
from .energy_star_settings_request import EnergyStarSettingsRequest
from .place_size_child import PlaceSizeChild
from .energy_star_pm_property import EnergyStarPmProperty
from .energy_star_pm_meter import EnergyStarPmMeter
from .energy_star_place_submission_status_child import EnergyStarPlaceSubmissionStatusChild
from .energy_star_place_submission_status_response import EnergyStarPlaceSubmissionStatusResponse
from .named_period import NamedPeriod
from .energy_star_task_place_child import EnergyStarTaskPlaceChild
from .energy_star_task_response import EnergyStarTaskResponse
from .energy_star_submission_place_child import EnergyStarSubmissionPlaceChild
from .energy_star_submission_request import EnergyStarSubmissionRequest
from .energy_star_place_metrics_request import EnergyStarPlaceMetricsRequest
from .energy_star_commodity_mapping_child import EnergyStarCommodityMappingChild
from .energy_star_commodity_mapping import EnergyStarCommodityMapping
from .environment import Environment
from .bill_action_historical_export import BillActionHistoricalExport
from .filter_data_response import FilterDataResponse
from .flag_type_child import FlagTypeChild
from .flag_status_child import FlagStatusChild
from .flag_action_child import FlagActionChild
from .flag_event_child import FlagEventChild
from .flag_response import FlagResponse
from .flag_edit import FlagEdit
from .flag_type_create import FlagTypeCreate
from .flag_list_action import FlagListAction
from .single_boolean import SingleBoolean
from .flag_widget_child import FlagWidgetChild
from .flag_widget import FlagWidget
from .gl_subcode_response import GLSubcodeResponse
from .gl_subcode_request import GLSubcodeRequest
from .gl_sub_code_child import GLSubCodeChild
from .general_ledger_response import GeneralLedgerResponse
from .gl_sub_code_child_request import GLSubCodeChildRequest
from .general_ledger_request import GeneralLedgerRequest
from .hierarchical_places import HierarchicalPlaces
from .hierarchical_places2 import HierarchicalPlaces2
from .hierarchical_cost_centers import HierarchicalCostCenters
from .hierarchical_cost_centers2 import HierarchicalCostCenters2
from .batch_settings import BatchSettings
from .bill_import_request import BillImportRequest
from .guid_response import GuidResponse
from .reading_import_profile_column import ReadingImportProfileColumn
from .estimated import Estimated
from .reading_import_profile import ReadingImportProfile
from .reading_import_request import ReadingImportRequest
from .reading_import_profile_request import ReadingImportProfileRequest
from .time_zone_child import TimeZoneChild
from .reading_import_profile_response import ReadingImportProfileResponse
from .bill_import_profile_observation import BillImportProfileObservation
from .bill_import_profile_column_mapping import BillImportProfileColumnMapping
from .bill_import_profile_response import BillImportProfileResponse
from .bill_import_profile_request import BillImportProfileRequest
from .list_response_list_item import ListResponseListItem
from .list_response_list_field import ListResponseListField
from .list_response import ListResponse
from .bill_export_options import BillExportOptions
from .bill_unexport_options import BillUnexportOptions
from .list_action_approve import ListActionApprove
from .list_action_export_hold import ListActionExportHold
from .list_action_void import ListActionVoid
from .bill_action_move_list import BillActionMoveList
from .dynamic_list_request import DynamicListRequest
from .list_column_edit import ListColumnEdit
from .list_copy import ListCopy
from .list_type_child import ListTypeChild
from .list_create_response import ListCreateResponse
from .list_edit import ListEdit
from .list_create import ListCreate
from .chargeback_processor_settings_for_splits import ChargebackProcessorSettingsForSplits
from .topmost_place import TopmostPlace
from .topmost_cost_center import TopmostCostCenter
from .claim import Claim
from .group_display_setting import GroupDisplaySetting
from .workflow_display_setting import WorkflowDisplaySetting
from .preference import Preference
from .time_format_response import TimeFormatResponse
from .license_feature_accounting_export import LicenseFeatureAccountingExport
from .license_feature_accrual_bills import LicenseFeatureAccrualBills
from .license_feature_chargebacks import LicenseFeatureChargebacks
from .license_feature_cost_avoidance import LicenseFeatureCostAvoidance
from .license_feature_interval_data_analysis import LicenseFeatureIntervalDataAnalysis
from .license_feature_report_designer import LicenseFeatureReportDesigner
from .license_feature_custom_benchmarks import LicenseFeatureCustomBenchmarks
from .accounting_settings import AccountingSettings
from .accounts import Accounts
from .accounts_module import AccountsModule
from .accrual_settings import AccrualSettings
from .cost_centers import CostCenters
from .move_accounts_between_vendors import MoveAccountsBetweenVendors
from .application_settings import ApplicationSettings
from .approve_bills import ApproveBills
from .bill_workflow_settings import BillWorkflowSettings
from .bills_and_batches import BillsAndBatches
from .export_bills import ExportBills
from .export_hold import ExportHold
from .move_existing_bills import MoveExistingBills
from .shared_bill_lists import SharedBillLists
from .unit_system_settings import UnitSystemSettings
from .update_approved_bills import UpdateApprovedBills
from .update_units_on_existing_bills import UpdateUnitsOnExistingBills
from .budgets_and_budget_versions import BudgetsAndBudgetVersions
from .chargebacks_module import ChargebacksModule
from .chargebacks import Chargebacks
from .chargeback_reversals import ChargebackReversals
from .meter_savings_settings import MeterSavingsSettings
from .savings_adjustments import SavingsAdjustments
from .manually_adjust_savings import ManuallyAdjustSavings
from .savings_engine import SavingsEngine
from .baseline_engine import BaselineEngine
from .global_cost_avoidance_settings import GlobalCostAvoidanceSettings
from .dashboard_and_maps_module import DashboardAndMapsModule
from .dashboard_administrator import DashboardAdministrator
from .public_dashboards_or_maps import PublicDashboardsOrMaps
from .shared_dashboards_or_maps import SharedDashboardsOrMaps
from .buildings_and_meters_module import BuildingsAndMetersModule
from .groups_and_benchmarks_module import GroupsAndBenchmarksModule
from .building_and_meter_groups import BuildingAndMeterGroups
from .buildings_and_organizations import BuildingsAndOrganizations
from .interval_data import IntervalData
from .interval_data_analysis import IntervalDataAnalysis
from .energystar_submissions import ENERGYSTARSubmissions
from .facility_projects import FacilityProjects
from .greenhouse_gas_administrator import GreenhouseGasAdministrator
from .interval_data_rollup import IntervalDataRollup
from .meters import Meters
from .normalization_settings import NormalizationSettings
from .weather_settings import WeatherSettings
from .reports_module import ReportsModule
from .distributed_reports_settings import DistributedReportsSettings
from .report_administrator import ReportAdministrator
from .report_groups import ReportGroups
from .shared_reports import SharedReports
from .reset_user_passwords import ResetUserPasswords
from .users_and_roles import UsersAndRoles
from .vendors_and_rates_module import VendorsAndRatesModule
from .rate_schedules import RateSchedules
from .vendors import Vendors
from .flagged_items import FlaggedItems
from .bill_list_administrator import BillListAdministrator
from .all_installed_reports import AllInstalledReports
from .permissions import Permissions
from .me import Me
from .preference_request import PreferenceRequest
from .me_request import MeRequest
from .required_address_child import RequiredAddressChild
from .meter_create import MeterCreate
from .channel_child import ChannelChild
from .meter_account_child import MeterAccountChild
from .primary_use_child import PrimaryUseChild
from .route_child import RouteChild
from .meter_response import MeterResponse
from .meter_edit import MeterEdit
from .meter_udf_response import MeterUDFResponse
from .meter_group_category_child import MeterGroupCategoryChild
from .meter_group_response import MeterGroupResponse
from .meter_group_member import MeterGroupMember
from .meter_rate_response import MeterRateResponse
from .meter_template_response import MeterTemplateResponse
from .meter_bill_response import MeterBillResponse
from .ghg_type_child import GHGTypeChild
from .ghg_factors_response import GHGFactorsResponse
from .meter_calendarized_use_vs_weather_response import MeterCalendarizedUseVsWeatherResponse
from .meter_digest_actual_and_calendarized_yearly_response_results import MeterDigestActualAndCalendarizedYearlyResponseResults
from .meter_digest_actual_and_calendarized_yearly_response import MeterDigestActualAndCalendarizedYearlyResponse
from .meter_digest_normalized_yearly_response_results import MeterDigestNormalizedYearlyResponseResults
from .meter_digest_normalized_yearly_response import MeterDigestNormalizedYearlyResponse
from .meter_cap_response import MeterCAPResponse
from .meter_digest_savings_yearly_response_results import MeterDigestSavingsYearlyResponseResults
from .meter_digest_savings_yearly_response import MeterDigestSavingsYearlyResponse
from .meter_digest_ghg_yearly_response_ghg_scope import MeterDigestGHGYearlyResponseGHGScope
from .meter_digest_ghg_yearly_response_results import MeterDigestGHGYearlyResponseResults
from .meter_digest_ghg_yearly_response_ghg_type import MeterDigestGHGYearlyResponseGHGType
from .meter_digest_ghg_yearly_response import MeterDigestGHGYearlyResponse
from .meter_digest_actual_and_calendarized_monthly_response_results import MeterDigestActualAndCalendarizedMonthlyResponseResults
from .meter_digest_actual_and_calendarized_monthly_response import MeterDigestActualAndCalendarizedMonthlyResponse
from .meter_digest_calendarized_trend_response_results import MeterDigestCalendarizedTrendResponseResults
from .meter_digest_calendarized_trend_response import MeterDigestCalendarizedTrendResponse
from .meter_digest_normalized_monthly_response_results import MeterDigestNormalizedMonthlyResponseResults
from .meter_digest_normalized_monthly_response import MeterDigestNormalizedMonthlyResponse
from .meter_digest_savings_monthly_response_results import MeterDigestSavingsMonthlyResponseResults
from .meter_digest_savings_monthly_response import MeterDigestSavingsMonthlyResponse
from .group_meter_group_response import GroupMeterGroupResponse
from .meter_group_request import MeterGroupRequest
from .meter_category_response import MeterCategoryResponse
from .meter_category_request import MeterCategoryRequest
from .meter_group_member_child import MeterGroupMemberChild
from .group_member_request import GroupMemberRequest
from .meter_group_digest_ranking_child import MeterGroupDigestRankingChild
from .meter_group_digest_ranking_response import MeterGroupDigestRankingResponse
from .meter_group_digest_demand_ranking_child import MeterGroupDigestDemandRankingChild
from .meter_group_digest_demand_ranking_response import MeterGroupDigestDemandRankingResponse
from .meter_group_digest_child import MeterGroupDigestChild
from .reading import Reading
from .reading_create import ReadingCreate
from .failed_readings import FailedReadings
from .failed_reading_response import FailedReadingResponse
from .reading_response import ReadingResponse
from .reading_delete import ReadingDelete
from .delete_reading_response import DeleteReadingResponse
from .reading_child import ReadingChild
from .reading_route_response import ReadingRouteResponse
from .readings_observation import ReadingsObservation
from .readings import Readings
from .weather_station_child import WeatherStationChild
from .benchmark_value import BenchmarkValue
from .benchmark_category_response import BenchmarkCategoryResponse
from .latest_benchmark_value import LatestBenchmarkValue
from .energy_star_rating_child import EnergyStarRatingChild
from .place_response import PlaceResponse
from .place_create import PlaceCreate
from .place_edit import PlaceEdit
from .place_size_create import PlaceSizeCreate
from .place_type_request import PlaceTypeRequest
from .place_udf_response import PlaceUDFResponse
from .energy_star_place_property_response import EnergyStarPlacePropertyResponse
from .place_energy_star_place_type_response import PlaceEnergyStarPlaceTypeResponse
from .energy_star_place_property_create import EnergyStarPlacePropertyCreate
from .place_energy_star_place_type_create import PlaceEnergyStarPlaceTypeCreate
from .place_energy_star_place_type_edit import PlaceEnergyStarPlaceTypeEdit
from .place_group_category_child import PlaceGroupCategoryChild
from .place_group_response import PlaceGroupResponse
from .place_group_member import PlaceGroupMember
from .energy_star_meter_link_child import EnergyStarMeterLinkChild
from .energy_star_place_link_response import EnergyStarPlaceLinkResponse
from .energy_star_meter_link_request import EnergyStarMeterLinkRequest
from .energy_star_place_link_request import EnergyStarPlaceLinkRequest
from .energy_star_place_metrics_response import EnergyStarPlaceMetricsResponse
from .energy_star_place_hierarchy_response import EnergyStarPlaceHierarchyResponse
from .benchmark_with_used_count_response import BenchmarkWithUsedCountResponse
from .benchmark_settings_response import BenchmarkSettingsResponse
from .benchmark_edit import BenchmarkEdit
from .benchmark_settings_edit import BenchmarkSettingsEdit
from .benchmark_value_request import BenchmarkValueRequest
from .benchmark_values_response import BenchmarkValuesResponse
from .place_digest_actual_and_calendarized_yearly_response_target_comparison import PlaceDigestActualAndCalendarizedYearlyResponseTargetComparison
from .place_digest_actual_and_calendarized_yearly_response_results import PlaceDigestActualAndCalendarizedYearlyResponseResults
from .place_digest_actual_and_calendarized_yearly_response_commodity_results import PlaceDigestActualAndCalendarizedYearlyResponseCommodityResults
from .place_digest_actual_and_calendarized_yearly_response_commodity_data import PlaceDigestActualAndCalendarizedYearlyResponseCommodityData
from .place_digest_actual_and_calendarized_yearly_response import PlaceDigestActualAndCalendarizedYearlyResponse
from .place_digest_normalized_yearly_response_target_comparison import PlaceDigestNormalizedYearlyResponseTargetComparison
from .place_digest_normalized_yearly_response_results import PlaceDigestNormalizedYearlyResponseResults
from .place_digest_normalized_yearly_response_commodity_results import PlaceDigestNormalizedYearlyResponseCommodityResults
from .place_digest_normalized_yearly_response_commodity_data import PlaceDigestNormalizedYearlyResponseCommodityData
from .place_digest_normalized_yearly_response import PlaceDigestNormalizedYearlyResponse
from .place_digest_savings_yearly_response_results import PlaceDigestSavingsYearlyResponseResults
from .place_digest_savings_yearly_response_commodity_data_commodity_results import PlaceDigestSavingsYearlyResponseCommodityDataCommodityResults
from .place_digest_savings_yearly_response_commodity_data import PlaceDigestSavingsYearlyResponseCommodityData
from .place_digest_savings_yearly_response import PlaceDigestSavingsYearlyResponse
from .place_digest_target_comparison_monthly_results import PlaceDigestTargetComparisonMonthlyResults
from .place_digest_target_comparison_monthly import PlaceDigestTargetComparisonMonthly
from .place_digest_actual_and_calendarized_monthly_response_commodity_results import PlaceDigestActualAndCalendarizedMonthlyResponseCommodityResults
from .place_digest_actual_and_calendarized_monthly_response_commodity_data import PlaceDigestActualAndCalendarizedMonthlyResponseCommodityData
from .place_digest_actual_and_calendarized_monthly_response_results import PlaceDigestActualAndCalendarizedMonthlyResponseResults
from .place_digest_actual_and_calendarized_monthly_response import PlaceDigestActualAndCalendarizedMonthlyResponse
from .place_digest_normalized_target_comparison_monthly_results import PlaceDigestNormalizedTargetComparisonMonthlyResults
from .place_digest_normalized_target_comparison_monthly import PlaceDigestNormalizedTargetComparisonMonthly
from .place_digest_normalized_commodity_target_comparison_monthly_commodity_results import PlaceDigestNormalizedCommodityTargetComparisonMonthlyCommodityResults
from .place_digest_normalized_commodity_target_comparison_monthly import PlaceDigestNormalizedCommodityTargetComparisonMonthly
from .place_digest_normalized_monthly_response_commodity_results import PlaceDigestNormalizedMonthlyResponseCommodityResults
from .place_digest_normalized_monthly_response_commodity_data import PlaceDigestNormalizedMonthlyResponseCommodityData
from .place_digest_normalized_monthly_response_results import PlaceDigestNormalizedMonthlyResponseResults
from .place_digest_normalized_monthly_response import PlaceDigestNormalizedMonthlyResponse
from .place_digest_savings_monthly_response_commodity_data_commodity_results import PlaceDigestSavingsMonthlyResponseCommodityDataCommodityResults
from .place_digest_savings_monthly_response_commodity_data import PlaceDigestSavingsMonthlyResponseCommodityData
from .place_digest_savings_monthly_response_results import PlaceDigestSavingsMonthlyResponseResults
from .place_digest_savings_monthly_response import PlaceDigestSavingsMonthlyResponse
from .place_digest_ghg_yearly_response_target_comparison import PlaceDigestGHGYearlyResponseTargetComparison
from .place_digest_ghg_yearly_response_results import PlaceDigestGHGYearlyResponseResults
from .place_digest_ghg_yearly_response_ghg_type import PlaceDigestGHGYearlyResponseGHGType
from .place_digest_ghg_yearly_response_ghg_scope import PlaceDigestGHGYearlyResponseGHGScope
from .place_digest_ghg_yearly_response import PlaceDigestGHGYearlyResponse
from .place_digest_ghg_monthly_response_results import PlaceDigestGHGMonthlyResponseResults
from .place_digest_ghg_monthly_response_target_comparison import PlaceDigestGHGMonthlyResponseTargetComparison
from .place_digest_ghg_monthly_response_ghg_type import PlaceDigestGHGMonthlyResponseGHGType
from .place_digest_ghg_monthly_response_ghg_scope import PlaceDigestGHGMonthlyResponseGHGScope
from .place_digest_ghg_monthly_response_ghg_commodity import PlaceDigestGHGMonthlyResponseGHGCommodity
from .place_digest_ghg_monthly_response import PlaceDigestGHGMonthlyResponse
from .place_digest_energy_use_intensity_eui_energy_project import PlaceDigestEnergyUseIntensityEuiEnergyProject
from .place_digest_energy_use_intensity_eui_commodity import PlaceDigestEnergyUseIntensityEuiCommodity
from .place_digest_energy_use_intensity import PlaceDigestEnergyUseIntensity
from .place_digest_energy_star_rating import PlaceDigestEnergyStarRating
from .group_place_group_response import GroupPlaceGroupResponse
from .place_group_request import PlaceGroupRequest
from .place_category_response import PlaceCategoryResponse
from .place_category_request import PlaceCategoryRequest
from .group_place_group_member import GroupPlaceGroupMember
from .place_group_digest_area_ranking_child import PlaceGroupDigestAreaRankingChild
from .place_group_digest_area_ranking_response import PlaceGroupDigestAreaRankingResponse
from .place_group_digest_benchmark_ranking_child import PlaceGroupDigestBenchmarkRankingChild
from .place_group_digest_benchmark_ranking_response import PlaceGroupDigestBenchmarkRankingResponse
from .place_group_digest_weather_ranking_child import PlaceGroupDigestWeatherRankingChild
from .place_group_digest_weather_ranking_response import PlaceGroupDigestWeatherRankingResponse
from .place_group_digest_child import PlaceGroupDigestChild
from .postal_code_response_weather_station import PostalCodeResponseWeatherStation
from .postal_code_response import PostalCodeResponse
from .primary_use_response import PrimaryUseResponse
from .primary_use_create import PrimaryUseCreate
from .version_response import VersionResponse
from .rate_response import RateResponse
from .rate_create import RateCreate
from .rate_version_response import RateVersionResponse
from .rate_version_request import RateVersionRequest
from .rate_edit import RateEdit
from .unit_type import UnitType
from .unit_response import UnitResponse
from .rate_digest_actual_yearly_response_results import RateDigestActualYearlyResponseResults
from .rate_digest_actual_yearly_response_commodity_results import RateDigestActualYearlyResponseCommodityResults
from .rate_digest_actual_yearly_response_commodity_data import RateDigestActualYearlyResponseCommodityData
from .rate_digest_actual_yearly_response import RateDigestActualYearlyResponse
from .report_group_request import ReportGroupRequest
from .report_type import ReportType
from .tag_child import TagChild
from .export_format_child import ExportFormatChild
from .report_child import ReportChild
from .report_group_response import ReportGroupResponse
from .report_category_child import ReportCategoryChild
from .specific_report_response import SpecificReportResponse
from .report_edit import ReportEdit
from .ok_result import OkResult
from .email_properties import EmailProperties
from .distributed_reports_configuration import DistributedReportsConfiguration
from .report_create import ReportCreate
from .quick_report import QuickReport
from .report_batch_child import ReportBatchChild
from .report_email import ReportEmail
from .report_mailer_child import ReportMailerChild
from .report_distribution_response import ReportDistributionResponse
from .route_response import RouteResponse
from .route_request import RouteRequest
from .route_meter import RouteMeter
from .meter_child_include_place_and_serial_number import MeterChildIncludePlaceAndSerialNumber
from .route_details_response import RouteDetailsResponse
from .observation_type_child_base import ObservationTypeChildBase
from .reading_child_base import ReadingChildBase
from .channel_latest_reading import ChannelLatestReading
from .meter_child_include_place_channel_latest_reading import MeterChildIncludePlaceChannelLatestReading
from .route_meter_channel_latest_reading_response import RouteMeterChannelLatestReadingResponse
from .reviewed import Reviewed
from .savings_meter_bill_response import SavingsMeterBillResponse
from .message import Message
from .savings_daily_data import SavingsDailyData
from .savings_meter_bill_daily_response import SavingsMeterBillDailyResponse
from .special_adjustment_type import SpecialAdjustmentType
from .special_adjustment_method import SpecialAdjustmentMethod
from .adjusted_cost_type_response import AdjustedCostTypeResponse
from .baseline_processor_request_baseline_bill import BaselineProcessorRequestBaselineBill
from .baseline_processor_request import BaselineProcessorRequest
from .baseline_processor_response_baseline_bill import BaselineProcessorResponseBaselineBill
from .baseline_processor_response import BaselineProcessorResponse
from .bulk_baseline_processor_request import BulkBaselineProcessorRequest
from .task_type import TaskType
from .cost_avoidance_settings import CostAvoidanceSettings
from .baseline_log import BaselineLog
from .savings_log import SavingsLog
from .cost_avoidance_task import CostAvoidanceTask
from .calculate_savings_request import CalculateSavingsRequest
from .manual_adjustment_request import ManualAdjustmentRequest
from .adjustment_base_method_child import AdjustmentBaseMethodChild
from .frequency import Frequency
from .special_adjustment_response import SpecialAdjustmentResponse
from .special_adjustment_create import SpecialAdjustmentCreate
from .special_adjustment_edit import SpecialAdjustmentEdit
from .other_savings_request import OtherSavingsRequest
from .other_savings_category import OtherSavingsCategory
from .other_savings_response import OtherSavingsResponse
from .other_savings_category_request import OtherSavingsCategoryRequest
from .bulk_meter_cost_avoidance_settings import BulkMeterCostAvoidanceSettings
from .generic_count import GenericCount
from .auc_range_response import AucRangeResponse
from .auc_range_request import AucRangeRequest
from .search_cost_center_child_search_cost_center import SearchCostCenterChildSearchCostCenter
from .search_cost_center_child import SearchCostCenterChild
from .search_account_child_search_account_child import SearchAccountChildSearchAccountChild
from .search_account_child import SearchAccountChild
from .search_parent_place_child import SearchParentPlaceChild
from .search_place_child_search_place_child import SearchPlaceChildSearchPlaceChild
from .search_place_child import SearchPlaceChild
from .search_meter_child_search_meter_child import SearchMeterChildSearchMeterChild
from .search_meter_child import SearchMeterChild
from .place_group_child import PlaceGroupChild
from .search_place_group import SearchPlaceGroup
from .search_response import SearchResponse
from .setup import Setup
from .report_group_child_response import ReportGroupChildResponse
from .user_response import UserResponse
from .user_create_request import UserCreateRequest
from .user_edit_request import UserEditRequest
from .tag_response import TagResponse
from .task_response import TaskResponse
from .task_edit import TaskEdit
from .version_child import VersionChild
from .template_response import TemplateResponse
from .observation_type import ObservationType
from .template_line import TemplateLine
from .template_version import TemplateVersion
from .create_template_from_bill import CreateTemplateFromBill
from .udf_select_value_response import UDFSelectValueResponse
from .udf_response import UDFResponse
from .udf_select_value_create import UDFSelectValueCreate
from .udf_create import UDFCreate
from .udf_select_value_edit import UDFSelectValueEdit
from .udf_edit import UDFEdit
from .udf_select_value_update import UDFSelectValueUpdate
from .udf_update import UDFUpdate
from .unit import Unit
from .rollup_unit_update_common_unit import RollupUnitUpdateCommonUnit
from .rollup_unit_update import RollupUnitUpdate
from .unit_system_meter_child import UnitSystemMeterChild
from .unit_system_template_child import UnitSystemTemplateChild
from .commodity_mismatch_child import CommodityMismatchChild
from .unit_mismatch_child import UnitMismatchChild
from .bill_template_unit_mismatch_response import BillTemplateUnitMismatchResponse
from .user_group_response import UserGroupResponse
from .user_group_request import UserGroupRequest
from .system_user_role_response import SystemUserRoleResponse
from .accounting_settings_class_permission import AccountingSettingsClassPermission
from .accounts_class_permission import AccountsClassPermission
from .accounts_module_class_permission import AccountsModuleClassPermission
from .accrual_settings_class_permission import AccrualSettingsClassPermission
from .cost_centers_class_permission import CostCentersClassPermission
from .move_accounts_between_vendors_class_permission import MoveAccountsBetweenVendorsClassPermission
from .application_settings_class_permission import ApplicationSettingsClassPermission
from .approve_bills_class_permission import ApproveBillsClassPermission
from .bill_workflow_settings_class_permission import BillWorkflowSettingsClassPermission
from .bills_and_batches_class_permission import BillsAndBatchesClassPermission
from .export_bills_class_permission import ExportBillsClassPermission
from .export_hold_class_permission import ExportHoldClassPermission
from .move_existing_bills_class_permission import MoveExistingBillsClassPermission
from .shared_bill_lists_class_permission import SharedBillListsClassPermission
from .unit_system_settings_class_permission import UnitSystemSettingsClassPermission
from .update_approved_bills_class_permission import UpdateApprovedBillsClassPermission
from .update_units_on_existing_bills_class_permission import UpdateUnitsOnExistingBillsClassPermission
from .budgets_and_budget_versions_class_permission import BudgetsAndBudgetVersionsClassPermission
from .chargebacks_module_class_permission import ChargebacksModuleClassPermission
from .chargebacks_class_permission import ChargebacksClassPermission
from .chargeback_reversals_class_permission import ChargebackReversalsClassPermission
from .meter_savings_settings_class_permission import MeterSavingsSettingsClassPermission
from .savings_adjustments_class_permission import SavingsAdjustmentsClassPermission
from .manually_adjust_savings_class_permission import ManuallyAdjustSavingsClassPermission
from .savings_engine_class_permission import SavingsEngineClassPermission
from .baseline_engine_class_permission import BaselineEngineClassPermission
from .global_cost_avoidance_settings_class_permission import GlobalCostAvoidanceSettingsClassPermission
from .dashboard_and_maps_module_class_permission import DashboardAndMapsModuleClassPermission
from .dashboard_administrator_class_permission import DashboardAdministratorClassPermission
from .public_dashboards_or_maps_class_permission import PublicDashboardsOrMapsClassPermission
from .shared_dashboards_or_maps_class_permission import SharedDashboardsOrMapsClassPermission
from .buildings_and_meters_module_class_permission import BuildingsAndMetersModuleClassPermission
from .groups_and_benchmarks_module_class_permission import GroupsAndBenchmarksModuleClassPermission
from .building_and_meter_groups_class_permission import BuildingAndMeterGroupsClassPermission
from .buildings_and_organizations_class_permission import BuildingsAndOrganizationsClassPermission
from .interval_data_class_permission import IntervalDataClassPermission
from .interval_data_analysis_class_permission import IntervalDataAnalysisClassPermission
from .energystar_submissions_class_permission import ENERGYSTARSubmissionsClassPermission
from .facility_projects_class_permission import FacilityProjectsClassPermission
from .greenhouse_gas_administrator_class_permission import GreenhouseGasAdministratorClassPermission
from .interval_data_rollup_class_permission import IntervalDataRollupClassPermission
from .meters_class_permission import MetersClassPermission
from .normalization_settings_class_permission import NormalizationSettingsClassPermission
from .weather_settings_class_permission import WeatherSettingsClassPermission
from .reports_module_class_permission import ReportsModuleClassPermission
from .distributed_reports_settings_class_permission import DistributedReportsSettingsClassPermission
from .report_administrator_class_permission import ReportAdministratorClassPermission
from .report_groups_class_permission import ReportGroupsClassPermission
from .shared_reports_class_permission import SharedReportsClassPermission
from .reset_user_passwords_class_permission import ResetUserPasswordsClassPermission
from .users_and_roles_class_permission import UsersAndRolesClassPermission
from .vendors_and_rates_module_class_permission import VendorsAndRatesModuleClassPermission
from .rate_schedules_class_permission import RateSchedulesClassPermission
from .vendors_class_permission import VendorsClassPermission
from .flagged_items_class_permission import FlaggedItemsClassPermission
from .bill_list_administrator_class_permission import BillListAdministratorClassPermission
from .all_installed_reports_class_permission import AllInstalledReportsClassPermission
from .permissions_request import PermissionsRequest
from .system_user_role_request import SystemUserRoleRequest
from .vendor_response import VendorResponse
from .vendor_request import VendorRequest
from .vendor_udf_response import VendorUDFResponse
from .vendor_contract_response import VendorContractResponse
from .vendor_digest_actual_yearly_response_results import VendorDigestActualYearlyResponseResults
from .vendor_digest_actual_yearly_response_commodity_results import VendorDigestActualYearlyResponseCommodityResults
from .vendor_digest_actual_yearly_response_commodity_data import VendorDigestActualYearlyResponseCommodityData
from .vendor_digest_actual_yearly_response import VendorDigestActualYearlyResponse
from .weather_import_settings import WeatherImportSettings
from .weather_station_summary import WeatherStationSummary
from .weather_import_result import WeatherImportResult
from .weather_station_response import WeatherStationResponse
from .webhook_create_request import WebhookCreateRequest
from .webhook_event_type_child import WebhookEventTypeChild
from .webhook_response import WebhookResponse
from .webhook_edit_request import WebhookEditRequest
from .webhook_log_response import WebhookLogResponse
from .webhook_log_request import WebhookLogRequest
from .webhook_log_details_response import WebhookLogDetailsResponse
from .widget_response import WidgetResponse
from .missing_bill_widget import MissingBillWidget
from .bills_overdue_from_vendor_response import BillsOverdueFromVendorResponse
from .map_place import MapPlace
from .energystar_place import EnergystarPlace
from .actionable_bill_counts import ActionableBillCounts
from .place_cost import PlaceCost
from .monthly_cap_trend import MonthlyCAPTrend
from .meter_cost import MeterCost
from .bill_header_workflow_child import BillHeaderWorkflowChild
from .batch_workflow_settings import BatchWorkflowSettings
from .export_workflow_settings import ExportWorkflowSettings
from .approval_workflow_settings import ApprovalWorkflowSettings
from .approval_workflow_child import ApprovalWorkflowChild
from .export_workflow_child import ExportWorkflowChild
from .chargeback_workflow_settings import ChargebackWorkflowSettings
from .workflow_settings_response import WorkflowSettingsResponse
from .batch_workflow_child import BatchWorkflowChild
from .approval_workflow_request_child import ApprovalWorkflowRequestChild
from .workflow_settings_request import WorkflowSettingsRequest

__all__ = [
    'AccountTypeChild',
    'CostCenterChild',
    'VendorChild',
    'ContactChild',
    'CustomerChild',
    'AddressChild',
    'GeneralLedgerChild',
    'PlaceTypeResponse',
    'PlaceChild',
    'CommodityChild',
    'VendorTypeChild',
    'AccountMeterChildWithSerialNumber',
    'UserChild',
    'UnitChild',
    'AccountResponse',
    'AccountEdit',
    'AccountCreate',
    'MeterTypeChild',
    'MeterChildSearch',
    'SearchAccountMeterBillEntry',
    'UDFValue',
    'DataTypeResponse',
    'UDFSelectValueEntityResponse',
    'UDFFieldChild',
    'AccountUDFResponse',
    'AccountMeterChild',
    'AccountRateResponse',
    'AccountTemplateResponse',
    'AccountAlertResponse',
    'AccountAlertRequest',
    'SingleValue',
    'UpdateResult',
    'AccountDigestActualYearlyResponseResults',
    'AccountDigestActualYearlyResponseCommodityResults',
    'AccountDigestActualYearlyResponseCommodityData',
    'AccountDigestActualYearlyResponse',
    'AccountDigestActualMonthlyResponseCommodityResults',
    'AccountDigestActualMonthlyResponseCommodityData',
    'AccountDigestActualMonthlyResponseResults',
    'AccountDigestActualMonthlyResponse',
    'AccountMeterRequest',
    'AccountChild',
    'MeterChild',
    'TemplateChild',
    'FormTemplateChild',
    'RateChild',
    'AccountRateChild',
    'AccountMeterResponse',
    'AccountMeterEdit',
    'AccountRateRequest',
    'AccountMeterRateResponse',
    'FormTemplateRequest',
    'FormTemplateResponse',
    'Activity',
    'AdminSettingsResponse',
    'AdminSettingsRequest',
    'AccountPeriodResponse',
    'AccountingSettingsResponse',
    'AccountPeriodRequest',
    'AccountingSettingsRequest',
    'TimeZoneResponse',
    'SystemUserRoleChild',
    'SystemSettingsResponse',
    'SystemSettingsRequest',
    'ApiKeyRequest',
    'ApiKeyCreateResponse',
    'ApiKeyResponse',
    'BillContainsLineItemDescriptionsSetting',
    'BillContainsLineItemTypesSetting',
    'TotalBillCostDoesNotMatchLineItemTypesSetting',
    'AuditSetting',
    'BillSignificantlyShorterOrLongerThanPreviousSetting',
    'TooManyConsecutiveEstimatedBillsSetting',
    'DueDateTooLongAfterBillEndSetting',
    'StatementDateTooLongAfterBillEndSetting',
    'AuditSettings',
    'LoginRequest',
    'ApiUser',
    'LoginResponse',
    'BatchCreate',
    'BatchResponse',
    'BatchEdit',
    'BatchChild',
    'ObservationMethodChild',
    'BillResponse',
    'BillMeterBodyLineCreate',
    'BillMeterCreate',
    'BillAccountBodyLineCreate',
    'BillCreate',
    'BillIdResponse',
    'BillMeterBodyLineEdit',
    'BillMeterEdit',
    'BillAccountBodyLineEdit',
    'BillEdit',
    'ObservationTypeChild',
    'BodylineResponse',
    'BillActionVoid',
    'BillHeaderUpdateBeginDateChild',
    'BillHeaderUpdateEndDateChild',
    'BillHeaderUpdateDueDateChild',
    'BillHeaderUpdateStatementDateChild',
    'BillHeaderUpdateControlCodeChild',
    'BillHeaderUpdateInvoiceNumberChild',
    'BillHeaderUpdateAccountPeriodChild',
    'BillHeaderUpdateBillingPeriodChild',
    'BillHeaderUpdateEstimatedChild',
    'BillHeaderUpdate',
    'BillActionHeaderUpdate',
    'BillHeaderUpdateResponseChild',
    'BillHeaderUpdateResponse',
    'BillActionApprove',
    'BillActionExportHold',
    'BillActionDelete',
    'BillDeleteActionResult',
    'ListIds',
    'DestinationAccountMeterChild',
    'DestinationAccountResponse',
    'MoveBillsDestination',
    'BillActionMove',
    'BillAccountMeterResponse',
    'BillHeaderChild',
    'BillEntryBodyLineWithNounChild',
    'BillEntryBodyLineChild',
    'BillEntryObservationTypeChild',
    'BillEntryBodyLine',
    'BillEntryMeterChild',
    'BillEntryResponse',
    'BillAccountMeterChild',
    'BillHistoryResponse',
    'BillExport',
    'BillUnexport',
    'BillActionSplit',
    'ChargebackWorkflowBase',
    'ChargebackWorkflowStepChild',
    'ChargebackTaskResponse',
    'AccountChildWithType',
    'DistributionVersionResponse',
    'DistributionVersionManage',
    'BillSplitPlaceSizeChild',
    'PlaceChildWithFloorArea',
    'FixedPercentageResponse',
    'FloorAreaSplitResponse',
    'MeterGroupChild',
    'DynamicPercentageBillSplitResponse',
    'BillSplitDetailsResponse',
    'FixedPercentage',
    'FloorAreaSplit',
    'DynamicPercentageBillSplit',
    'BillSplitDetailsRequest',
    'ChargebackTaskVersionResponse',
    'BillSplitParentDetailsResponse',
    'BillViewAddressChild',
    'BillViewVendorChild',
    'BillViewAccountChild',
    'BillViewMeterChild',
    'BodylineChild',
    'BillCalendarizedHistory',
    'BillViewResponse',
    'ObservationRule',
    'ChannelChildWithObservationType',
    'FixedAmountResponse',
    'CopyFromMeterResponse',
    'SumResponse',
    'SubtractResponse',
    'CalculationResponse',
    'CalculatedBillUseResponse',
    'RateChildResponse',
    'CalculatedBillCostResponse',
    'CalculatedBillDemandResponse',
    'GenericBodylineResponse',
    'CalculatedBillDetailsResponse',
    'FixedUseRequest',
    'CopyMeterRequest',
    'SumRequest',
    'SubtractRequest',
    'CalculationRequest',
    'CalculatedBillUseRequest',
    'FixedUnitCostRequest',
    'CalculatedBillCostRequest',
    'FixedDemandRequest',
    'CalculatedBillDemandRequest',
    'GenericBodylineRequest',
    'ObservationMethod',
    'DeviceChannelChild',
    'ChannelResponse',
    'ChannelEdit',
    'ChannelCreate',
    'QuickFilter',
    'ChargebackProcessorSettings',
    'ChargebackProcessorSettingsWithoutFilters',
    'ChargebackTaskRequest',
    'ChargebackWorkflowStep',
    'ChargebackWorkflowResponse',
    'ChargebackWorkflowStepCreate',
    'ChargebackWorkflowCreate',
    'ChargebackWorkflowStepEdit',
    'ChargebackWorkflowEdit',
    'AssignVersionsToStep',
    'BillingPeriodUseUnitChild',
    'BillingPeriodCostUnitChild',
    'BillingPeriodUseCostChild',
    'BillingPeriodUseUnitDeltaChild',
    'BillingPeriodCostUnitDeltaChild',
    'BillingPeriodUseCostDeltaChild',
    'ChargebackWorkflowDigestSplitChild',
    'ChargebackWorkflowDigestChild',
    'ChargebackWorkflowDigestResponse',
    'Commodity',
    'CommodityDigestActualYearlyResponseResults',
    'CommodityDigestActualYearlyResponseCommodityResults',
    'CommodityDigestActualYearlyResponseCommodityData',
    'CommodityDigestActualYearlyResponse',
    'CostCenterAccountChild',
    'CostCenterResponse',
    'CostCenterCreate',
    'CostCenterDigestActualYearlyResponseResults',
    'CostCenterDigestActualYearlyResponseCommodityResults',
    'CostCenterDigestActualYearlyResponseCommodityData',
    'CostCenterDigestActualYearlyResponse',
    'CostCenterDigestActualMonthlyResponseCommodityResults',
    'CostCenterDigestActualMonthlyResponseCommodityData',
    'CostCenterDigestActualMonthlyResponseResults',
    'CostCenterDigestActualMonthlyResponse',
    'CustomerResponse',
    'DashboardResponse',
    'DashboardCreate',
    'DashboardEdit',
    'DashboardCopy',
    'FilterResponse',
    'SpecificWidgetResponse',
    'FilterEdit',
    'WidgetCreate',
    'WidgetEdit',
    'UserGroupChild',
    'ShareResponse',
    'ShareRequest',
    'ToggleVisible',
    'EnergySavingsUnit',
    'EnergySavingsChild',
    'CostSavingsUnit',
    'CostSavingsChild',
    'EnergyProjectPlaceChild',
    'EnergyProjectType',
    'EnergyProjectResponse',
    'EnergyProjectEdit',
    'EnergyProjectCreate',
    'EnergyProjectTypeCreate',
    'ProjectManagerResponse',
    'EnergyStarSettingsResponse',
    'EnergyStarSettingsRequest',
    'PlaceSizeChild',
    'EnergyStarPmProperty',
    'EnergyStarPmMeter',
    'EnergyStarPlaceSubmissionStatusChild',
    'EnergyStarPlaceSubmissionStatusResponse',
    'NamedPeriod',
    'EnergyStarTaskPlaceChild',
    'EnergyStarTaskResponse',
    'EnergyStarSubmissionPlaceChild',
    'EnergyStarSubmissionRequest',
    'EnergyStarPlaceMetricsRequest',
    'EnergyStarCommodityMappingChild',
    'EnergyStarCommodityMapping',
    'Environment',
    'BillActionHistoricalExport',
    'FilterDataResponse',
    'FlagTypeChild',
    'FlagStatusChild',
    'FlagActionChild',
    'FlagEventChild',
    'FlagResponse',
    'FlagEdit',
    'FlagTypeCreate',
    'FlagListAction',
    'SingleBoolean',
    'FlagWidgetChild',
    'FlagWidget',
    'GLSubcodeResponse',
    'GLSubcodeRequest',
    'GLSubCodeChild',
    'GeneralLedgerResponse',
    'GLSubCodeChildRequest',
    'GeneralLedgerRequest',
    'HierarchicalPlaces',
    'HierarchicalPlaces2',
    'HierarchicalCostCenters',
    'HierarchicalCostCenters2',
    'BatchSettings',
    'BillImportRequest',
    'GuidResponse',
    'ReadingImportProfileColumn',
    'Estimated',
    'ReadingImportProfile',
    'ReadingImportRequest',
    'ReadingImportProfileRequest',
    'TimeZoneChild',
    'ReadingImportProfileResponse',
    'BillImportProfileObservation',
    'BillImportProfileColumnMapping',
    'BillImportProfileResponse',
    'BillImportProfileRequest',
    'ListResponseListItem',
    'ListResponseListField',
    'ListResponse',
    'BillExportOptions',
    'BillUnexportOptions',
    'ListActionApprove',
    'ListActionExportHold',
    'ListActionVoid',
    'BillActionMoveList',
    'DynamicListRequest',
    'ListColumnEdit',
    'ListCopy',
    'ListTypeChild',
    'ListCreateResponse',
    'ListEdit',
    'ListCreate',
    'ChargebackProcessorSettingsForSplits',
    'TopmostPlace',
    'TopmostCostCenter',
    'Claim',
    'GroupDisplaySetting',
    'WorkflowDisplaySetting',
    'Preference',
    'TimeFormatResponse',
    'LicenseFeatureAccountingExport',
    'LicenseFeatureAccrualBills',
    'LicenseFeatureChargebacks',
    'LicenseFeatureCostAvoidance',
    'LicenseFeatureIntervalDataAnalysis',
    'LicenseFeatureReportDesigner',
    'LicenseFeatureCustomBenchmarks',
    'AccountingSettings',
    'Accounts',
    'AccountsModule',
    'AccrualSettings',
    'CostCenters',
    'MoveAccountsBetweenVendors',
    'ApplicationSettings',
    'ApproveBills',
    'BillWorkflowSettings',
    'BillsAndBatches',
    'ExportBills',
    'ExportHold',
    'MoveExistingBills',
    'SharedBillLists',
    'UnitSystemSettings',
    'UpdateApprovedBills',
    'UpdateUnitsOnExistingBills',
    'BudgetsAndBudgetVersions',
    'ChargebacksModule',
    'Chargebacks',
    'ChargebackReversals',
    'MeterSavingsSettings',
    'SavingsAdjustments',
    'ManuallyAdjustSavings',
    'SavingsEngine',
    'BaselineEngine',
    'GlobalCostAvoidanceSettings',
    'DashboardAndMapsModule',
    'DashboardAdministrator',
    'PublicDashboardsOrMaps',
    'SharedDashboardsOrMaps',
    'BuildingsAndMetersModule',
    'GroupsAndBenchmarksModule',
    'BuildingAndMeterGroups',
    'BuildingsAndOrganizations',
    'IntervalData',
    'IntervalDataAnalysis',
    'ENERGYSTARSubmissions',
    'FacilityProjects',
    'GreenhouseGasAdministrator',
    'IntervalDataRollup',
    'Meters',
    'NormalizationSettings',
    'WeatherSettings',
    'ReportsModule',
    'DistributedReportsSettings',
    'ReportAdministrator',
    'ReportGroups',
    'SharedReports',
    'ResetUserPasswords',
    'UsersAndRoles',
    'VendorsAndRatesModule',
    'RateSchedules',
    'Vendors',
    'FlaggedItems',
    'BillListAdministrator',
    'AllInstalledReports',
    'Permissions',
    'Me',
    'PreferenceRequest',
    'MeRequest',
    'RequiredAddressChild',
    'MeterCreate',
    'ChannelChild',
    'MeterAccountChild',
    'PrimaryUseChild',
    'RouteChild',
    'MeterResponse',
    'MeterEdit',
    'MeterUDFResponse',
    'MeterGroupCategoryChild',
    'MeterGroupResponse',
    'MeterGroupMember',
    'MeterRateResponse',
    'MeterTemplateResponse',
    'MeterBillResponse',
    'GHGTypeChild',
    'GHGFactorsResponse',
    'MeterCalendarizedUseVsWeatherResponse',
    'MeterDigestActualAndCalendarizedYearlyResponseResults',
    'MeterDigestActualAndCalendarizedYearlyResponse',
    'MeterDigestNormalizedYearlyResponseResults',
    'MeterDigestNormalizedYearlyResponse',
    'MeterCAPResponse',
    'MeterDigestSavingsYearlyResponseResults',
    'MeterDigestSavingsYearlyResponse',
    'MeterDigestGHGYearlyResponseGHGScope',
    'MeterDigestGHGYearlyResponseResults',
    'MeterDigestGHGYearlyResponseGHGType',
    'MeterDigestGHGYearlyResponse',
    'MeterDigestActualAndCalendarizedMonthlyResponseResults',
    'MeterDigestActualAndCalendarizedMonthlyResponse',
    'MeterDigestCalendarizedTrendResponseResults',
    'MeterDigestCalendarizedTrendResponse',
    'MeterDigestNormalizedMonthlyResponseResults',
    'MeterDigestNormalizedMonthlyResponse',
    'MeterDigestSavingsMonthlyResponseResults',
    'MeterDigestSavingsMonthlyResponse',
    'GroupMeterGroupResponse',
    'MeterGroupRequest',
    'MeterCategoryResponse',
    'MeterCategoryRequest',
    'MeterGroupMemberChild',
    'GroupMemberRequest',
    'MeterGroupDigestRankingChild',
    'MeterGroupDigestRankingResponse',
    'MeterGroupDigestDemandRankingChild',
    'MeterGroupDigestDemandRankingResponse',
    'MeterGroupDigestChild',
    'Reading',
    'ReadingCreate',
    'FailedReadings',
    'FailedReadingResponse',
    'ReadingResponse',
    'ReadingDelete',
    'DeleteReadingResponse',
    'ReadingChild',
    'ReadingRouteResponse',
    'ReadingsObservation',
    'Readings',
    'WeatherStationChild',
    'BenchmarkValue',
    'BenchmarkCategoryResponse',
    'LatestBenchmarkValue',
    'EnergyStarRatingChild',
    'PlaceResponse',
    'PlaceCreate',
    'PlaceEdit',
    'PlaceSizeCreate',
    'PlaceTypeRequest',
    'PlaceUDFResponse',
    'EnergyStarPlacePropertyResponse',
    'PlaceEnergyStarPlaceTypeResponse',
    'EnergyStarPlacePropertyCreate',
    'PlaceEnergyStarPlaceTypeCreate',
    'PlaceEnergyStarPlaceTypeEdit',
    'PlaceGroupCategoryChild',
    'PlaceGroupResponse',
    'PlaceGroupMember',
    'EnergyStarMeterLinkChild',
    'EnergyStarPlaceLinkResponse',
    'EnergyStarMeterLinkRequest',
    'EnergyStarPlaceLinkRequest',
    'EnergyStarPlaceMetricsResponse',
    'EnergyStarPlaceHierarchyResponse',
    'BenchmarkWithUsedCountResponse',
    'BenchmarkSettingsResponse',
    'BenchmarkEdit',
    'BenchmarkSettingsEdit',
    'BenchmarkValueRequest',
    'BenchmarkValuesResponse',
    'PlaceDigestActualAndCalendarizedYearlyResponseTargetComparison',
    'PlaceDigestActualAndCalendarizedYearlyResponseResults',
    'PlaceDigestActualAndCalendarizedYearlyResponseCommodityResults',
    'PlaceDigestActualAndCalendarizedYearlyResponseCommodityData',
    'PlaceDigestActualAndCalendarizedYearlyResponse',
    'PlaceDigestNormalizedYearlyResponseTargetComparison',
    'PlaceDigestNormalizedYearlyResponseResults',
    'PlaceDigestNormalizedYearlyResponseCommodityResults',
    'PlaceDigestNormalizedYearlyResponseCommodityData',
    'PlaceDigestNormalizedYearlyResponse',
    'PlaceDigestSavingsYearlyResponseResults',
    'PlaceDigestSavingsYearlyResponseCommodityDataCommodityResults',
    'PlaceDigestSavingsYearlyResponseCommodityData',
    'PlaceDigestSavingsYearlyResponse',
    'PlaceDigestTargetComparisonMonthlyResults',
    'PlaceDigestTargetComparisonMonthly',
    'PlaceDigestActualAndCalendarizedMonthlyResponseCommodityResults',
    'PlaceDigestActualAndCalendarizedMonthlyResponseCommodityData',
    'PlaceDigestActualAndCalendarizedMonthlyResponseResults',
    'PlaceDigestActualAndCalendarizedMonthlyResponse',
    'PlaceDigestNormalizedTargetComparisonMonthlyResults',
    'PlaceDigestNormalizedTargetComparisonMonthly',
    'PlaceDigestNormalizedCommodityTargetComparisonMonthlyCommodityResults',
    'PlaceDigestNormalizedCommodityTargetComparisonMonthly',
    'PlaceDigestNormalizedMonthlyResponseCommodityResults',
    'PlaceDigestNormalizedMonthlyResponseCommodityData',
    'PlaceDigestNormalizedMonthlyResponseResults',
    'PlaceDigestNormalizedMonthlyResponse',
    'PlaceDigestSavingsMonthlyResponseCommodityDataCommodityResults',
    'PlaceDigestSavingsMonthlyResponseCommodityData',
    'PlaceDigestSavingsMonthlyResponseResults',
    'PlaceDigestSavingsMonthlyResponse',
    'PlaceDigestGHGYearlyResponseTargetComparison',
    'PlaceDigestGHGYearlyResponseResults',
    'PlaceDigestGHGYearlyResponseGHGType',
    'PlaceDigestGHGYearlyResponseGHGScope',
    'PlaceDigestGHGYearlyResponse',
    'PlaceDigestGHGMonthlyResponseResults',
    'PlaceDigestGHGMonthlyResponseTargetComparison',
    'PlaceDigestGHGMonthlyResponseGHGType',
    'PlaceDigestGHGMonthlyResponseGHGScope',
    'PlaceDigestGHGMonthlyResponseGHGCommodity',
    'PlaceDigestGHGMonthlyResponse',
    'PlaceDigestEnergyUseIntensityEuiEnergyProject',
    'PlaceDigestEnergyUseIntensityEuiCommodity',
    'PlaceDigestEnergyUseIntensity',
    'PlaceDigestEnergyStarRating',
    'GroupPlaceGroupResponse',
    'PlaceGroupRequest',
    'PlaceCategoryResponse',
    'PlaceCategoryRequest',
    'GroupPlaceGroupMember',
    'PlaceGroupDigestAreaRankingChild',
    'PlaceGroupDigestAreaRankingResponse',
    'PlaceGroupDigestBenchmarkRankingChild',
    'PlaceGroupDigestBenchmarkRankingResponse',
    'PlaceGroupDigestWeatherRankingChild',
    'PlaceGroupDigestWeatherRankingResponse',
    'PlaceGroupDigestChild',
    'PostalCodeResponseWeatherStation',
    'PostalCodeResponse',
    'PrimaryUseResponse',
    'PrimaryUseCreate',
    'VersionResponse',
    'RateResponse',
    'RateCreate',
    'RateVersionResponse',
    'RateVersionRequest',
    'RateEdit',
    'UnitType',
    'UnitResponse',
    'RateDigestActualYearlyResponseResults',
    'RateDigestActualYearlyResponseCommodityResults',
    'RateDigestActualYearlyResponseCommodityData',
    'RateDigestActualYearlyResponse',
    'ReportGroupRequest',
    'ReportType',
    'TagChild',
    'ExportFormatChild',
    'ReportChild',
    'ReportGroupResponse',
    'ReportCategoryChild',
    'SpecificReportResponse',
    'ReportEdit',
    'OkResult',
    'EmailProperties',
    'DistributedReportsConfiguration',
    'ReportCreate',
    'QuickReport',
    'ReportBatchChild',
    'ReportEmail',
    'ReportMailerChild',
    'ReportDistributionResponse',
    'RouteResponse',
    'RouteRequest',
    'RouteMeter',
    'MeterChildIncludePlaceAndSerialNumber',
    'RouteDetailsResponse',
    'ObservationTypeChildBase',
    'ReadingChildBase',
    'ChannelLatestReading',
    'MeterChildIncludePlaceChannelLatestReading',
    'RouteMeterChannelLatestReadingResponse',
    'Reviewed',
    'SavingsMeterBillResponse',
    'Message',
    'SavingsDailyData',
    'SavingsMeterBillDailyResponse',
    'SpecialAdjustmentType',
    'SpecialAdjustmentMethod',
    'AdjustedCostTypeResponse',
    'BaselineProcessorRequestBaselineBill',
    'BaselineProcessorRequest',
    'BaselineProcessorResponseBaselineBill',
    'BaselineProcessorResponse',
    'BulkBaselineProcessorRequest',
    'TaskType',
    'CostAvoidanceSettings',
    'BaselineLog',
    'SavingsLog',
    'CostAvoidanceTask',
    'CalculateSavingsRequest',
    'ManualAdjustmentRequest',
    'AdjustmentBaseMethodChild',
    'Frequency',
    'SpecialAdjustmentResponse',
    'SpecialAdjustmentCreate',
    'SpecialAdjustmentEdit',
    'OtherSavingsRequest',
    'OtherSavingsCategory',
    'OtherSavingsResponse',
    'OtherSavingsCategoryRequest',
    'BulkMeterCostAvoidanceSettings',
    'GenericCount',
    'AucRangeResponse',
    'AucRangeRequest',
    'SearchCostCenterChildSearchCostCenter',
    'SearchCostCenterChild',
    'SearchAccountChildSearchAccountChild',
    'SearchAccountChild',
    'SearchParentPlaceChild',
    'SearchPlaceChildSearchPlaceChild',
    'SearchPlaceChild',
    'SearchMeterChildSearchMeterChild',
    'SearchMeterChild',
    'PlaceGroupChild',
    'SearchPlaceGroup',
    'SearchResponse',
    'Setup',
    'ReportGroupChildResponse',
    'UserResponse',
    'UserCreateRequest',
    'UserEditRequest',
    'TagResponse',
    'TaskResponse',
    'TaskEdit',
    'VersionChild',
    'TemplateResponse',
    'ObservationType',
    'TemplateLine',
    'TemplateVersion',
    'CreateTemplateFromBill',
    'UDFSelectValueResponse',
    'UDFResponse',
    'UDFSelectValueCreate',
    'UDFCreate',
    'UDFSelectValueEdit',
    'UDFEdit',
    'UDFSelectValueUpdate',
    'UDFUpdate',
    'Unit',
    'RollupUnitUpdateCommonUnit',
    'RollupUnitUpdate',
    'UnitSystemMeterChild',
    'UnitSystemTemplateChild',
    'CommodityMismatchChild',
    'UnitMismatchChild',
    'BillTemplateUnitMismatchResponse',
    'UserGroupResponse',
    'UserGroupRequest',
    'SystemUserRoleResponse',
    'AccountingSettingsClassPermission',
    'AccountsClassPermission',
    'AccountsModuleClassPermission',
    'AccrualSettingsClassPermission',
    'CostCentersClassPermission',
    'MoveAccountsBetweenVendorsClassPermission',
    'ApplicationSettingsClassPermission',
    'ApproveBillsClassPermission',
    'BillWorkflowSettingsClassPermission',
    'BillsAndBatchesClassPermission',
    'ExportBillsClassPermission',
    'ExportHoldClassPermission',
    'MoveExistingBillsClassPermission',
    'SharedBillListsClassPermission',
    'UnitSystemSettingsClassPermission',
    'UpdateApprovedBillsClassPermission',
    'UpdateUnitsOnExistingBillsClassPermission',
    'BudgetsAndBudgetVersionsClassPermission',
    'ChargebacksModuleClassPermission',
    'ChargebacksClassPermission',
    'ChargebackReversalsClassPermission',
    'MeterSavingsSettingsClassPermission',
    'SavingsAdjustmentsClassPermission',
    'ManuallyAdjustSavingsClassPermission',
    'SavingsEngineClassPermission',
    'BaselineEngineClassPermission',
    'GlobalCostAvoidanceSettingsClassPermission',
    'DashboardAndMapsModuleClassPermission',
    'DashboardAdministratorClassPermission',
    'PublicDashboardsOrMapsClassPermission',
    'SharedDashboardsOrMapsClassPermission',
    'BuildingsAndMetersModuleClassPermission',
    'GroupsAndBenchmarksModuleClassPermission',
    'BuildingAndMeterGroupsClassPermission',
    'BuildingsAndOrganizationsClassPermission',
    'IntervalDataClassPermission',
    'IntervalDataAnalysisClassPermission',
    'ENERGYSTARSubmissionsClassPermission',
    'FacilityProjectsClassPermission',
    'GreenhouseGasAdministratorClassPermission',
    'IntervalDataRollupClassPermission',
    'MetersClassPermission',
    'NormalizationSettingsClassPermission',
    'WeatherSettingsClassPermission',
    'ReportsModuleClassPermission',
    'DistributedReportsSettingsClassPermission',
    'ReportAdministratorClassPermission',
    'ReportGroupsClassPermission',
    'SharedReportsClassPermission',
    'ResetUserPasswordsClassPermission',
    'UsersAndRolesClassPermission',
    'VendorsAndRatesModuleClassPermission',
    'RateSchedulesClassPermission',
    'VendorsClassPermission',
    'FlaggedItemsClassPermission',
    'BillListAdministratorClassPermission',
    'AllInstalledReportsClassPermission',
    'PermissionsRequest',
    'SystemUserRoleRequest',
    'VendorResponse',
    'VendorRequest',
    'VendorUDFResponse',
    'VendorContractResponse',
    'VendorDigestActualYearlyResponseResults',
    'VendorDigestActualYearlyResponseCommodityResults',
    'VendorDigestActualYearlyResponseCommodityData',
    'VendorDigestActualYearlyResponse',
    'WeatherImportSettings',
    'WeatherStationSummary',
    'WeatherImportResult',
    'WeatherStationResponse',
    'WebhookCreateRequest',
    'WebhookEventTypeChild',
    'WebhookResponse',
    'WebhookEditRequest',
    'WebhookLogResponse',
    'WebhookLogRequest',
    'WebhookLogDetailsResponse',
    'WidgetResponse',
    'MissingBillWidget',
    'BillsOverdueFromVendorResponse',
    'MapPlace',
    'EnergystarPlace',
    'ActionableBillCounts',
    'PlaceCost',
    'MonthlyCAPTrend',
    'MeterCost',
    'BillHeaderWorkflowChild',
    'BatchWorkflowSettings',
    'ExportWorkflowSettings',
    'ApprovalWorkflowSettings',
    'ApprovalWorkflowChild',
    'ExportWorkflowChild',
    'ChargebackWorkflowSettings',
    'WorkflowSettingsResponse',
    'BatchWorkflowChild',
    'ApprovalWorkflowRequestChild',
    'WorkflowSettingsRequest',
]



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceDigestActualAndCalendarizedMonthlyResponseCommodityData(Model):
    """PlaceDigestActualAndCalendarizedMonthlyResponseCommodityData.

    :param commodity_code: The commodity code
    :type commodity_code: str
    :param commodity_info: The commodity info
    :type commodity_info: str
    :param commodity_id: The commodity identifier
    :type commodity_id: int
    :param common_use_unit:
    :type common_use_unit: ~energycap.sdk.models.UnitChild
    :param common_demand_unit:
    :type common_demand_unit: ~energycap.sdk.models.UnitChild
    :param cost_unit:
    :type cost_unit: ~energycap.sdk.models.UnitChild
    :param results: An array of commodity monthly data
    :type results:
     list[~energycap.sdk.models.PlaceDigestActualAndCalendarizedMonthlyResponseCommodityResults]
    :param target_comparison:
    :type target_comparison:
     ~energycap.sdk.models.PlaceDigestTargetComparisonMonthly
    """

    _attribute_map = {
        'commodity_code': {'key': 'commodityCode', 'type': 'str'},
        'commodity_info': {'key': 'commodityInfo', 'type': 'str'},
        'commodity_id': {'key': 'commodityId', 'type': 'int'},
        'common_use_unit': {'key': 'commonUseUnit', 'type': 'UnitChild'},
        'common_demand_unit': {'key': 'commonDemandUnit', 'type': 'UnitChild'},
        'cost_unit': {'key': 'costUnit', 'type': 'UnitChild'},
        'results': {'key': 'results', 'type': '[PlaceDigestActualAndCalendarizedMonthlyResponseCommodityResults]'},
        'target_comparison': {'key': 'targetComparison', 'type': 'PlaceDigestTargetComparisonMonthly'},
    }

    def __init__(self, commodity_code=None, commodity_info=None, commodity_id=None, common_use_unit=None, common_demand_unit=None, cost_unit=None, results=None, target_comparison=None):
        super(PlaceDigestActualAndCalendarizedMonthlyResponseCommodityData, self).__init__()
        self.commodity_code = commodity_code
        self.commodity_info = commodity_info
        self.commodity_id = commodity_id
        self.common_use_unit = common_use_unit
        self.common_demand_unit = common_demand_unit
        self.cost_unit = cost_unit
        self.results = results
        self.target_comparison = target_comparison



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarSettingsResponse(Model):
    """EnergyStarSettingsResponse.

    :param pm_account_manager_full_name: Full name of Portfolio Account
     Manager
    :type pm_account_manager_full_name: str
    :param pm_account_manager_user_name: User name of Portfolio Account
     Manager
    :type pm_account_manager_user_name: str
    :param notification_recipients: List of e-mail notification recipients
    :type notification_recipients: list[str]
    :param earliest_submission_period: The earliest period to submit
    :type earliest_submission_period: int
    """

    _attribute_map = {
        'pm_account_manager_full_name': {'key': 'pmAccountManagerFullName', 'type': 'str'},
        'pm_account_manager_user_name': {'key': 'pmAccountManagerUserName', 'type': 'str'},
        'notification_recipients': {'key': 'notificationRecipients', 'type': '[str]'},
        'earliest_submission_period': {'key': 'earliestSubmissionPeriod', 'type': 'int'},
    }

    def __init__(self, pm_account_manager_full_name=None, pm_account_manager_user_name=None, notification_recipients=None, earliest_submission_period=None):
        super(EnergyStarSettingsResponse, self).__init__()
        self.pm_account_manager_full_name = pm_account_manager_full_name
        self.pm_account_manager_user_name = pm_account_manager_user_name
        self.notification_recipients = notification_recipients
        self.earliest_submission_period = earliest_submission_period



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillIdResponse(Model):
    """BillIdResponse.

    :param bill_id: The bill identifier
    :type bill_id: int
    """

    _attribute_map = {
        'bill_id': {'key': 'billId', 'type': 'int'},
    }

    def __init__(self, bill_id=None):
        super(BillIdResponse, self).__init__()
        self.bill_id = bill_id



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceDigestGHGMonthlyResponseResults(Model):
    """PlaceDigestGHGMonthlyResponseResults.

    :param period_name: Calendar Period Name
    :type period_name: str
    :param calendar_period: Calendar Period
    :type calendar_period: int
    :param calendar_year: Calendar Year
    :type calendar_year: int
    :param fiscal_period: Fiscal Period
    :type fiscal_period: int
    :param fiscal_year: Fiscal Year
    :type fiscal_year: int
    :param equivalent_co2_emissions: Equivalent CO2 emissions
    :type equivalent_co2_emissions: float
    """

    _attribute_map = {
        'period_name': {'key': 'periodName', 'type': 'str'},
        'calendar_period': {'key': 'calendarPeriod', 'type': 'int'},
        'calendar_year': {'key': 'calendarYear', 'type': 'int'},
        'fiscal_period': {'key': 'fiscalPeriod', 'type': 'int'},
        'fiscal_year': {'key': 'fiscalYear', 'type': 'int'},
        'equivalent_co2_emissions': {'key': 'equivalentCO2Emissions', 'type': 'float'},
    }

    def __init__(self, period_name=None, calendar_period=None, calendar_year=None, fiscal_period=None, fiscal_year=None, equivalent_co2_emissions=None):
        super(PlaceDigestGHGMonthlyResponseResults, self).__init__()
        self.period_name = period_name
        self.calendar_period = calendar_period
        self.calendar_year = calendar_year
        self.fiscal_period = fiscal_period
        self.fiscal_year = fiscal_year
        self.equivalent_co2_emissions = equivalent_co2_emissions



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class WorkflowSettingsRequest(Model):
    """WorkflowSettingsRequest.

    :param batch:
    :type batch: ~energycap.sdk.models.BatchWorkflowChild
    :param approval:
    :type approval: ~energycap.sdk.models.ApprovalWorkflowRequestChild
    :param ap_export:
    :type ap_export: ~energycap.sdk.models.ExportWorkflowChild
    :param gl_export:
    :type gl_export: ~energycap.sdk.models.ExportWorkflowChild
    :param chargeback:
    :type chargeback: ~energycap.sdk.models.ChargebackWorkflowSettings
    """

    _validation = {
        'batch': {'required': True},
        'approval': {'required': True},
    }

    _attribute_map = {
        'batch': {'key': 'batch', 'type': 'BatchWorkflowChild'},
        'approval': {'key': 'approval', 'type': 'ApprovalWorkflowRequestChild'},
        'ap_export': {'key': 'apExport', 'type': 'ExportWorkflowChild'},
        'gl_export': {'key': 'glExport', 'type': 'ExportWorkflowChild'},
        'chargeback': {'key': 'chargeback', 'type': 'ChargebackWorkflowSettings'},
    }

    def __init__(self, batch, approval, ap_export=None, gl_export=None, chargeback=None):
        super(WorkflowSettingsRequest, self).__init__()
        self.batch = batch
        self.approval = approval
        self.ap_export = ap_export
        self.gl_export = gl_export
        self.chargeback = chargeback



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class WebhookLogDetailsResponse(Model):
    """WebhookLogDetailsResponse.

    :param url: The URL that the webhook is configured for
    :type url: str
    :param request: The request that was sent from the webhook (headers and
     body)
    :type request: str
    :param response: The response that was received from the configured url
     (headers and body)
    :type response: str
    :param result: The HTTP status code that was received from the configured
     url
    :type result: str
    """

    _attribute_map = {
        'url': {'key': 'url', 'type': 'str'},
        'request': {'key': 'request', 'type': 'str'},
        'response': {'key': 'response', 'type': 'str'},
        'result': {'key': 'result', 'type': 'str'},
    }

    def __init__(self, url=None, request=None, response=None, result=None):
        super(WebhookLogDetailsResponse, self).__init__()
        self.url = url
        self.request = request
        self.response = response
        self.result = result



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UnitMismatchChild(Model):
    """UnitMismatchChild.

    :param unit:
    :type unit: ~energycap.sdk.models.UnitChild
    :param count:
    :type count: int
    """

    _attribute_map = {
        'unit': {'key': 'unit', 'type': 'UnitChild'},
        'count': {'key': 'count', 'type': 'int'},
    }

    def __init__(self, unit=None, count=None):
        super(UnitMismatchChild, self).__init__()
        self.unit = unit
        self.count = count



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AucRangeResponse(Model):
    """AucRangeResponse.

    :param commodity_cap_id: Unique identifier for the commodity's average
     unit cost range
    :type commodity_cap_id: int
    :param commodity:
    :type commodity: ~energycap.sdk.models.CommodityChild
    :param lower_limit_multiplier: When the current bill's average unit cost
     is LOWER than this multiplier x the baseline bill's average unit cost,
     then the cost avoidance processor will use the average unit cost from the
     baseline bill instead of the current bill
    :type lower_limit_multiplier: float
    :param upper_limit_multiplier: When the current bill's average unit cost
     is HIGHER than this multiplier x the baseline bill's average unit cost,
     then the cost avoidance processor will use the average unit cost from the
     baseline bill instead of the current bill
    :type upper_limit_multiplier: float
    :param is_used: Indicates whether or not this commodity is used; i.e.
     there are meters that have been created with this commodity which are
     included in cost avoidance
    :type is_used: bool
    """

    _attribute_map = {
        'commodity_cap_id': {'key': 'commodityCapId', 'type': 'int'},
        'commodity': {'key': 'commodity', 'type': 'CommodityChild'},
        'lower_limit_multiplier': {'key': 'lowerLimitMultiplier', 'type': 'float'},
        'upper_limit_multiplier': {'key': 'upperLimitMultiplier', 'type': 'float'},
        'is_used': {'key': 'isUsed', 'type': 'bool'},
    }

    def __init__(self, commodity_cap_id=None, commodity=None, lower_limit_multiplier=None, upper_limit_multiplier=None, is_used=None):
        super(AucRangeResponse, self).__init__()
        self.commodity_cap_id = commodity_cap_id
        self.commodity = commodity
        self.lower_limit_multiplier = lower_limit_multiplier
        self.upper_limit_multiplier = upper_limit_multiplier
        self.is_used = is_used



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillViewResponse(Model):
    """BillViewResponse.

    :param bill_id: The bill identifier
    :type bill_id: int
    :param void: Indicates if the bill has been voided
    :type void: bool
    :param from_vendor: Indicates if the bill is from a vendor
    :type from_vendor: bool
    :param creation_method: The method used to create the bill Automatic,
     Manual, Estimated, Simulated, Accrual, or Adjustment
    :type creation_method: str
    :param accrual: Indicates if the bill is an accrual
    :type accrual: bool
    :param accrual_reversed: Indicates if the bill is a reversed accrual
    :type accrual_reversed: bool
    :param batch:
    :type batch: ~energycap.sdk.models.BatchChild
    :param batch_end_date: The date the batch was closed
    :type batch_end_date: datetime
    :param hide_batch_code: Do y'all need to have a batch code?
    :type hide_batch_code: bool
    :param created_by:
    :type created_by: ~energycap.sdk.models.UserChild
    :param created_date: The date and time the bill was created
    :type created_date: datetime
    :param modified_by:
    :type modified_by: ~energycap.sdk.models.UserChild
    :param modified_date: The date and time of the most recent modification
    :type modified_date: datetime
    :param approved: Indicates if the bill has been approved
    :type approved: bool
    :param approve_date: The date and time the bill was approved
    :type approve_date: datetime
    :param approved_by:
    :type approved_by: ~energycap.sdk.models.UserChild
    :param has_been_split: Indicates if the bill has been split
    :type has_been_split: bool
    :param was_split_date: The date and time the bill was split
    :type was_split_date: datetime
    :param export_hold: Indicates if the bill is being withheld from bill
     exports
    :type export_hold: bool
    :param ap_exported: Indicates if the bill has been ap exported
    :type ap_exported: bool
    :param ap_export_date: The date and time the bill was ap exported
    :type ap_export_date: datetime
    :param ap_exported_by:
    :type ap_exported_by: ~energycap.sdk.models.UserChild
    :param gl_exported: Indicates if the bill has been gl exported
    :type gl_exported: bool
    :param gl_exported_by:
    :type gl_exported_by: ~energycap.sdk.models.UserChild
    :param gl_export_date: The date and time the bill was exported to gl
    :type gl_export_date: datetime
    :param check_number: The number of the check that the bill was paid with
    :type check_number: str
    :param check_date: The date and time of the check
    :type check_date: datetime
    :param pay_status: The payment status of the bill
    :type pay_status: str
    :param cleared_date: The date and time that the check cleared
    :type cleared_date: datetime
    :param account:
    :type account: ~energycap.sdk.models.BillViewAccountChild
    :param begin_date: The bill's begin date
    :type begin_date: datetime
    :param end_date: The bill's end date
    :type end_date: datetime
    :param billing_period: The bill's billing period
    :type billing_period: int
    :param days: The bill's number of days
    :type days: int
    :param account_period: The bill's accounting period
    :type account_period: int
    :param account_period_name: The bill's accounting period name
    :type account_period_name: str
    :param hide_account_period: Is account period required?
    :type hide_account_period: bool
    :param hide_account_year: Is account year required?  What is it?
    :type hide_account_year: bool
    :param total_cost: The bill's total cost
    :type total_cost: float
    :param balance: The bill's balance
    :type balance: float
    :param estimated: Indicates if the bill is estimated
    :type estimated: bool
    :param hide_estimated: Is estimated flag required?
    :type hide_estimated: bool
    :param statement_date: The date of the billing statement
    :type statement_date: datetime
    :param hide_statement_date: Is statement date required?
    :type hide_statement_date: bool
    :param due_date: The date and time the bill is due
    :type due_date: datetime
    :param hide_due_date: Is due date required?
    :type hide_due_date: bool
    :param invoice_number: The bill's invoice number
    :type invoice_number: str
    :param hide_invoice_number: Is Invoice Number Required?
    :type hide_invoice_number: bool
    :param control_code: The bill's control code
    :type control_code: str
    :param hide_control_code: Is control code required?
    :type hide_control_code: bool
    :param bill_image_url: The fully qualified url to the bill image
    :type bill_image_url: str
    :param bill_note: Bill note
    :type bill_note: str
    :param next_reading: The bill's next reading date
    :type next_reading: datetime
    :param hide_next_reading: Is next reading date required?
    :type hide_next_reading: bool
    :param prior_bill_id: Bill ID for the bill on this account that
     immediately preceeds this bill (used for navigating back to the prior
     bill)
    :type prior_bill_id: int
    :param next_bill_id: Bill ID for the bill on this account that immediately
     follows this bill (used for navigating to the next bill)
    :type next_bill_id: int
    :param bill_history: The bill history
    :type bill_history: list[~energycap.sdk.models.BillHistoryResponse]
    :param meters: The list of meters on the bill
    :type meters: list[~energycap.sdk.models.BillViewMeterChild]
    :param body_lines: The list of body lines on the bill
    :type body_lines: list[~energycap.sdk.models.BodylineChild]
    :param bill_account_meters: The list of account-meter summaries on the
     bill
    :type bill_account_meters:
     list[~energycap.sdk.models.BillAccountMeterChild]
    :param calendarized_history: Calendarized history informtion for the
     account
    :type calendarized_history:
     list[~energycap.sdk.models.BillCalendarizedHistory]
    """

    _attribute_map = {
        'bill_id': {'key': 'billId', 'type': 'int'},
        'void': {'key': 'void', 'type': 'bool'},
        'from_vendor': {'key': 'fromVendor', 'type': 'bool'},
        'creation_method': {'key': 'creationMethod', 'type': 'str'},
        'accrual': {'key': 'accrual', 'type': 'bool'},
        'accrual_reversed': {'key': 'accrualReversed', 'type': 'bool'},
        'batch': {'key': 'batch', 'type': 'BatchChild'},
        'batch_end_date': {'key': 'batchEndDate', 'type': 'iso-8601'},
        'hide_batch_code': {'key': 'hideBatchCode', 'type': 'bool'},
        'created_by': {'key': 'createdBy', 'type': 'UserChild'},
        'created_date': {'key': 'createdDate', 'type': 'iso-8601'},
        'modified_by': {'key': 'modifiedBy', 'type': 'UserChild'},
        'modified_date': {'key': 'modifiedDate', 'type': 'iso-8601'},
        'approved': {'key': 'approved', 'type': 'bool'},
        'approve_date': {'key': 'approveDate', 'type': 'iso-8601'},
        'approved_by': {'key': 'approvedBy', 'type': 'UserChild'},
        'has_been_split': {'key': 'hasBeenSplit', 'type': 'bool'},
        'was_split_date': {'key': 'wasSplitDate', 'type': 'iso-8601'},
        'export_hold': {'key': 'exportHold', 'type': 'bool'},
        'ap_exported': {'key': 'apExported', 'type': 'bool'},
        'ap_export_date': {'key': 'apExportDate', 'type': 'iso-8601'},
        'ap_exported_by': {'key': 'apExportedBy', 'type': 'UserChild'},
        'gl_exported': {'key': 'glExported', 'type': 'bool'},
        'gl_exported_by': {'key': 'glExportedBy', 'type': 'UserChild'},
        'gl_export_date': {'key': 'glExportDate', 'type': 'iso-8601'},
        'check_number': {'key': 'checkNumber', 'type': 'str'},
        'check_date': {'key': 'checkDate', 'type': 'iso-8601'},
        'pay_status': {'key': 'payStatus', 'type': 'str'},
        'cleared_date': {'key': 'clearedDate', 'type': 'iso-8601'},
        'account': {'key': 'account', 'type': 'BillViewAccountChild'},
        'begin_date': {'key': 'beginDate', 'type': 'iso-8601'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
        'billing_period': {'key': 'billingPeriod', 'type': 'int'},
        'days': {'key': 'days', 'type': 'int'},
        'account_period': {'key': 'accountPeriod', 'type': 'int'},
        'account_period_name': {'key': 'accountPeriodName', 'type': 'str'},
        'hide_account_period': {'key': 'hideAccountPeriod', 'type': 'bool'},
        'hide_account_year': {'key': 'hideAccountYear', 'type': 'bool'},
        'total_cost': {'key': 'totalCost', 'type': 'float'},
        'balance': {'key': 'balance', 'type': 'float'},
        'estimated': {'key': 'estimated', 'type': 'bool'},
        'hide_estimated': {'key': 'hideEstimated', 'type': 'bool'},
        'statement_date': {'key': 'statementDate', 'type': 'iso-8601'},
        'hide_statement_date': {'key': 'hideStatementDate', 'type': 'bool'},
        'due_date': {'key': 'dueDate', 'type': 'iso-8601'},
        'hide_due_date': {'key': 'hideDueDate', 'type': 'bool'},
        'invoice_number': {'key': 'invoiceNumber', 'type': 'str'},
        'hide_invoice_number': {'key': 'hideInvoiceNumber', 'type': 'bool'},
        'control_code': {'key': 'controlCode', 'type': 'str'},
        'hide_control_code': {'key': 'hideControlCode', 'type': 'bool'},
        'bill_image_url': {'key': 'billImageUrl', 'type': 'str'},
        'bill_note': {'key': 'billNote', 'type': 'str'},
        'next_reading': {'key': 'nextReading', 'type': 'iso-8601'},
        'hide_next_reading': {'key': 'hideNextReading', 'type': 'bool'},
        'prior_bill_id': {'key': 'priorBillId', 'type': 'int'},
        'next_bill_id': {'key': 'nextBillId', 'type': 'int'},
        'bill_history': {'key': 'billHistory', 'type': '[BillHistoryResponse]'},
        'meters': {'key': 'meters', 'type': '[BillViewMeterChild]'},
        'body_lines': {'key': 'bodyLines', 'type': '[BodylineChild]'},
        'bill_account_meters': {'key': 'billAccountMeters', 'type': '[BillAccountMeterChild]'},
        'calendarized_history': {'key': 'calendarizedHistory', 'type': '[BillCalendarizedHistory]'},
    }

    def __init__(self, bill_id=None, void=None, from_vendor=None, creation_method=None, accrual=None, accrual_reversed=None, batch=None, batch_end_date=None, hide_batch_code=None, created_by=None, created_date=None, modified_by=None, modified_date=None, approved=None, approve_date=None, approved_by=None, has_been_split=None, was_split_date=None, export_hold=None, ap_exported=None, ap_export_date=None, ap_exported_by=None, gl_exported=None, gl_exported_by=None, gl_export_date=None, check_number=None, check_date=None, pay_status=None, cleared_date=None, account=None, begin_date=None, end_date=None, billing_period=None, days=None, account_period=None, account_period_name=None, hide_account_period=None, hide_account_year=None, total_cost=None, balance=None, estimated=None, hide_estimated=None, statement_date=None, hide_statement_date=None, due_date=None, hide_due_date=None, invoice_number=None, hide_invoice_number=None, control_code=None, hide_control_code=None, bill_image_url=None, bill_note=None, next_reading=None, hide_next_reading=None, prior_bill_id=None, next_bill_id=None, bill_history=None, meters=None, body_lines=None, bill_account_meters=None, calendarized_history=None):
        super(BillViewResponse, self).__init__()
        self.bill_id = bill_id
        self.void = void
        self.from_vendor = from_vendor
        self.creation_method = creation_method
        self.accrual = accrual
        self.accrual_reversed = accrual_reversed
        self.batch = batch
        self.batch_end_date = batch_end_date
        self.hide_batch_code = hide_batch_code
        self.created_by = created_by
        self.created_date = created_date
        self.modified_by = modified_by
        self.modified_date = modified_date
        self.approved = approved
        self.approve_date = approve_date
        self.approved_by = approved_by
        self.has_been_split = has_been_split
        self.was_split_date = was_split_date
        self.export_hold = export_hold
        self.ap_exported = ap_exported
        self.ap_export_date = ap_export_date
        self.ap_exported_by = ap_exported_by
        self.gl_exported = gl_exported
        self.gl_exported_by = gl_exported_by
        self.gl_export_date = gl_export_date
        self.check_number = check_number
        self.check_date = check_date
        self.pay_status = pay_status
        self.cleared_date = cleared_date
        self.account = account
        self.begin_date = begin_date
        self.end_date = end_date
        self.billing_period = billing_period
        self.days = days
        self.account_period = account_period
        self.account_period_name = account_period_name
        self.hide_account_period = hide_account_period
        self.hide_account_year = hide_account_year
        self.total_cost = total_cost
        self.balance = balance
        self.estimated = estimated
        self.hide_estimated = hide_estimated
        self.statement_date = statement_date
        self.hide_statement_date = hide_statement_date
        self.due_date = due_date
        self.hide_due_date = hide_due_date
        self.invoice_number = invoice_number
        self.hide_invoice_number = hide_invoice_number
        self.control_code = control_code
        self.hide_control_code = hide_control_code
        self.bill_image_url = bill_image_url
        self.bill_note = bill_note
        self.next_reading = next_reading
        self.hide_next_reading = hide_next_reading
        self.prior_bill_id = prior_bill_id
        self.next_bill_id = next_bill_id
        self.bill_history = bill_history
        self.meters = meters
        self.body_lines = body_lines
        self.bill_account_meters = bill_account_meters
        self.calendarized_history = calendarized_history



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class Commodity(Model):
    """Commodity.

    :param commodity_id: The Commodity ID
    :type commodity_id: int
    :param commodity_code: The Commodity Code
    :type commodity_code: str
    :param commodity_info: The Commodity Info
    :type commodity_info: str
    :param in_use_by_vendor: Flag to indicate whether any vendor is assigned
     this commodity
     through an Account Meter relationship
    :type in_use_by_vendor: bool
    :param common_use_unit:
    :type common_use_unit: ~energycap.sdk.models.UnitChild
    :param common_demand_unit:
    :type common_demand_unit: ~energycap.sdk.models.UnitChild
    """

    _attribute_map = {
        'commodity_id': {'key': 'commodityId', 'type': 'int'},
        'commodity_code': {'key': 'commodityCode', 'type': 'str'},
        'commodity_info': {'key': 'commodityInfo', 'type': 'str'},
        'in_use_by_vendor': {'key': 'inUseByVendor', 'type': 'bool'},
        'common_use_unit': {'key': 'commonUseUnit', 'type': 'UnitChild'},
        'common_demand_unit': {'key': 'commonDemandUnit', 'type': 'UnitChild'},
    }

    def __init__(self, commodity_id=None, commodity_code=None, commodity_info=None, in_use_by_vendor=None, common_use_unit=None, common_demand_unit=None):
        super(Commodity, self).__init__()
        self.commodity_id = commodity_id
        self.commodity_code = commodity_code
        self.commodity_info = commodity_info
        self.in_use_by_vendor = in_use_by_vendor
        self.common_use_unit = common_use_unit
        self.common_demand_unit = common_demand_unit



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TopmostCostCenter(Model):
    """TopmostCostCenter.

    :param is_multi_topmost_cost_center: User's topmost combines multiple cost
     centers
    :type is_multi_topmost_cost_center: bool
    :param multi_topmost_cost_centers:
    :type multi_topmost_cost_centers:
     list[~energycap.sdk.models.CostCenterChild]
    :param cost_center_id: The cost center identifier
    :type cost_center_id: int
    :param cost_center_code: The cost center code
    :type cost_center_code: str
    :param cost_center_info: The cost center info
    :type cost_center_info: str
    """

    _attribute_map = {
        'is_multi_topmost_cost_center': {'key': 'isMultiTopmostCostCenter', 'type': 'bool'},
        'multi_topmost_cost_centers': {'key': 'multiTopmostCostCenters', 'type': '[CostCenterChild]'},
        'cost_center_id': {'key': 'costCenterId', 'type': 'int'},
        'cost_center_code': {'key': 'costCenterCode', 'type': 'str'},
        'cost_center_info': {'key': 'costCenterInfo', 'type': 'str'},
    }

    def __init__(self, is_multi_topmost_cost_center=None, multi_topmost_cost_centers=None, cost_center_id=None, cost_center_code=None, cost_center_info=None):
        super(TopmostCostCenter, self).__init__()
        self.is_multi_topmost_cost_center = is_multi_topmost_cost_center
        self.multi_topmost_cost_centers = multi_topmost_cost_centers
        self.cost_center_id = cost_center_id
        self.cost_center_code = cost_center_code
        self.cost_center_info = cost_center_info



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ChannelChildWithObservationType(Model):
    """ChannelChildWithObservationType.

    :param type:
    :type type: ~energycap.sdk.models.ObservationTypeChild
    :param rule:
    :type rule: ~energycap.sdk.models.ObservationRule
    :param channel_code: The channel code
     Combines
     observationTypeCode:unitCode:observationMethodCode:observationRuleCode:interval
     in minutes
    :type channel_code: str
    :param channel_id: The channel identifier
    :type channel_id: int
    :param interval: The channel interval in seconds.
     Monthly = 2592000
     Weekly = 604800
     Daily = 86400
     Hourly = 3600
     Thirty_Minutes = 1800
     Fifteen_Minutes = 900
    :type interval: int
    """

    _attribute_map = {
        'type': {'key': 'type', 'type': 'ObservationTypeChild'},
        'rule': {'key': 'rule', 'type': 'ObservationRule'},
        'channel_code': {'key': 'channelCode', 'type': 'str'},
        'channel_id': {'key': 'channelId', 'type': 'int'},
        'interval': {'key': 'interval', 'type': 'int'},
    }

    def __init__(self, type=None, rule=None, channel_code=None, channel_id=None, interval=None):
        super(ChannelChildWithObservationType, self).__init__()
        self.type = type
        self.rule = rule
        self.channel_code = channel_code
        self.channel_id = channel_id
        self.interval = interval



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarPmMeter(Model):
    """EnergyStarPmMeter.

    :param pm_meter_id: The Portfolio Manager meter identifier
    :type pm_meter_id: long
    :param pm_meter_name: The Portfolio Manager meter name
    :type pm_meter_name: str
    :param pm_commodity_code: The Portfolio Manager commodity
    :type pm_commodity_code: str
    :param pm_unit_code: The Portfolio Manager unit of measure
    :type pm_unit_code: str
    :param meter:
    :type meter: ~energycap.sdk.models.MeterChild
    :param unit:
    :type unit: ~energycap.sdk.models.UnitChild
    """

    _attribute_map = {
        'pm_meter_id': {'key': 'pmMeterId', 'type': 'long'},
        'pm_meter_name': {'key': 'pmMeterName', 'type': 'str'},
        'pm_commodity_code': {'key': 'pmCommodityCode', 'type': 'str'},
        'pm_unit_code': {'key': 'pmUnitCode', 'type': 'str'},
        'meter': {'key': 'meter', 'type': 'MeterChild'},
        'unit': {'key': 'unit', 'type': 'UnitChild'},
    }

    def __init__(self, pm_meter_id=None, pm_meter_name=None, pm_commodity_code=None, pm_unit_code=None, meter=None, unit=None):
        super(EnergyStarPmMeter, self).__init__()
        self.pm_meter_id = pm_meter_id
        self.pm_meter_name = pm_meter_name
        self.pm_commodity_code = pm_commodity_code
        self.pm_unit_code = pm_unit_code
        self.meter = meter
        self.unit = unit



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BatchSettings(Model):
    """BatchSettings.

    :param batch_mode:  <span class='property-internal'>One of use existing
     batch, new batch, new self-contained batch </span>
    :type batch_mode: str
    :param new_batch_code: optional- if not provided, we will autocreate the
     batch code.
     If useExistingBatch is true, this value will be ignored <span
     class='property-internal'>Must be between 0 and 255 characters</span>
    :type new_batch_code: str
    """

    _validation = {
        'new_batch_code': {'max_length': 255, 'min_length': 0},
    }

    _attribute_map = {
        'batch_mode': {'key': 'batchMode', 'type': 'str'},
        'new_batch_code': {'key': 'newBatchCode', 'type': 'str'},
    }

    def __init__(self, batch_mode=None, new_batch_code=None):
        super(BatchSettings, self).__init__()
        self.batch_mode = batch_mode
        self.new_batch_code = new_batch_code



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReportDistributionResponse(Model):
    """ReportDistributionResponse.

    :param user:
    :type user: ~energycap.sdk.models.UserChild
    :param mailers: Array of report mailers processed, with their results
    :type mailers: list[~energycap.sdk.models.ReportMailerChild]
    """

    _attribute_map = {
        'user': {'key': 'user', 'type': 'UserChild'},
        'mailers': {'key': 'mailers', 'type': '[ReportMailerChild]'},
    }

    def __init__(self, user=None, mailers=None):
        super(ReportDistributionResponse, self).__init__()
        self.user = user
        self.mailers = mailers



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class WebhookLogRequest(Model):
    """WebhookLogRequest.

    :param status_code: The HTTP status code <span
     class='property-internal'>Required (defined)</span>
    :type status_code: int
    :param response: The response JSON <span
     class='property-internal'>Required (defined)</span>
    :type response: str
    """

    _attribute_map = {
        'status_code': {'key': 'statusCode', 'type': 'int'},
        'response': {'key': 'response', 'type': 'str'},
    }

    def __init__(self, status_code=None, response=None):
        super(WebhookLogRequest, self).__init__()
        self.status_code = status_code
        self.response = response



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CopyFromMeterResponse(Model):
    """Defines an account and meter whose use or cost will be copied when
    calculating a bill.

    :param meter:
    :type meter: ~energycap.sdk.models.MeterChild
    :param percentage: Percentage of use or cost to copy
    :type percentage: float
    """

    _attribute_map = {
        'meter': {'key': 'meter', 'type': 'MeterChild'},
        'percentage': {'key': 'percentage', 'type': 'float'},
    }

    def __init__(self, meter=None, percentage=None):
        super(CopyFromMeterResponse, self).__init__()
        self.meter = meter
        self.percentage = percentage



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SearchMeterChildSearchMeterChild(Model):
    """SearchMeterChildSearchMeterChild.

    :param meter_id: The meter identifier
    :type meter_id: int
    :param meter_code: The meter code <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 32 characters</span>
    :type meter_code: str
    :param meter_info: The meter info <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 50 characters</span>
    :type meter_info: str
    :param accounts: The collection of accounts
    :type accounts: list[~energycap.sdk.models.MeterAccountChild]
    :param commodity:
    :type commodity: ~energycap.sdk.models.CommodityChild
    :param meter_type:
    :type meter_type: ~energycap.sdk.models.MeterTypeChild
    :param postal_code: The address postal code
    :type postal_code: str
    :param city: The address city
    :type city: str
    :param state: The address state
    :type state: str
    :param country: The address country
    :type country: str
    :param line1: The address first line
    :type line1: str
    :param line2: The address second line
    :type line2: str
    :param bill_entry_note: The bill entry note
    :type bill_entry_note: str
    :param include_in_energy_star: Indicates if the building is included in
     ENERGY STAR submissions
    :type include_in_energy_star: bool
    :param properties: An array of meter properties
    :type properties: dict[str, str]
    :param parent_path: The collection of places representing the path to its
     parent
    :type parent_path: list[~energycap.sdk.models.SearchParentPlaceChild]
    :param active: Indicates whether the Meter is Active
    :type active: bool
    :param is_calculated_meter: Indicates whether the Meter is a calculated
     meter
    :type is_calculated_meter: bool
    :param is_split_parent_meter: Indicates whether the Meter is a parent of a
     split
    :type is_split_parent_meter: bool
    :param is_split_child_meter: Indicates whether the Meter is a child of a
     split
    :type is_split_child_meter: bool
    """

    _validation = {
        'meter_code': {'required': True, 'max_length': 32, 'min_length': 0},
        'meter_info': {'required': True, 'max_length': 50, 'min_length': 0},
    }

    _attribute_map = {
        'meter_id': {'key': 'meterId', 'type': 'int'},
        'meter_code': {'key': 'meterCode', 'type': 'str'},
        'meter_info': {'key': 'meterInfo', 'type': 'str'},
        'accounts': {'key': 'accounts', 'type': '[MeterAccountChild]'},
        'commodity': {'key': 'commodity', 'type': 'CommodityChild'},
        'meter_type': {'key': 'meterType', 'type': 'MeterTypeChild'},
        'postal_code': {'key': 'postalCode', 'type': 'str'},
        'city': {'key': 'city', 'type': 'str'},
        'state': {'key': 'state', 'type': 'str'},
        'country': {'key': 'country', 'type': 'str'},
        'line1': {'key': 'line1', 'type': 'str'},
        'line2': {'key': 'line2', 'type': 'str'},
        'bill_entry_note': {'key': 'billEntryNote', 'type': 'str'},
        'include_in_energy_star': {'key': 'includeInEnergyStar', 'type': 'bool'},
        'properties': {'key': 'properties', 'type': '{str}'},
        'parent_path': {'key': 'parentPath', 'type': '[SearchParentPlaceChild]'},
        'active': {'key': 'active', 'type': 'bool'},
        'is_calculated_meter': {'key': 'isCalculatedMeter', 'type': 'bool'},
        'is_split_parent_meter': {'key': 'isSplitParentMeter', 'type': 'bool'},
        'is_split_child_meter': {'key': 'isSplitChildMeter', 'type': 'bool'},
    }

    def __init__(self, meter_code, meter_info, meter_id=None, accounts=None, commodity=None, meter_type=None, postal_code=None, city=None, state=None, country=None, line1=None, line2=None, bill_entry_note=None, include_in_energy_star=None, properties=None, parent_path=None, active=None, is_calculated_meter=None, is_split_parent_meter=None, is_split_child_meter=None):
        super(SearchMeterChildSearchMeterChild, self).__init__()
        self.meter_id = meter_id
        self.meter_code = meter_code
        self.meter_info = meter_info
        self.accounts = accounts
        self.commodity = commodity
        self.meter_type = meter_type
        self.postal_code = postal_code
        self.city = city
        self.state = state
        self.country = country
        self.line1 = line1
        self.line2 = line2
        self.bill_entry_note = bill_entry_note
        self.include_in_energy_star = include_in_energy_star
        self.properties = properties
        self.parent_path = parent_path
        self.active = active
        self.is_calculated_meter = is_calculated_meter
        self.is_split_parent_meter = is_split_parent_meter
        self.is_split_child_meter = is_split_child_meter



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class NamedPeriod(Model):
    """NamedPeriod.

    :param period_name:
    :type period_name: str
    :param period:
    :type period: int
    """

    _attribute_map = {
        'period_name': {'key': 'periodName', 'type': 'str'},
        'period': {'key': 'period', 'type': 'int'},
    }

    def __init__(self, period_name=None, period=None):
        super(NamedPeriod, self).__init__()
        self.period_name = period_name
        self.period = period



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillAccountMeterResponse(Model):
    """BillAccountMeterResponse.

    :param bill_id: The bill identifier
    :type bill_id: int
    :param billing_period: The bill's billing period
    :type billing_period: int
    :param begin_date: The bill's begin date
    :type begin_date: datetime
    :param end_date: The bill's end date
    :type end_date: datetime
    :param days: The number of days the bill covers
    :type days: int
    :param account:
    :type account: ~energycap.sdk.models.AccountChild
    :param meter:
    :type meter: ~energycap.sdk.models.MeterChild
    :param global_use: Global use
    :type global_use: float
    :param global_use_per_day: Global use per day
    :type global_use_per_day: float
    :param global_use_unit:
    :type global_use_unit: ~energycap.sdk.models.UnitChild
    :param native_use: Native use
    :type native_use: float
    :param native_use_per_day: Native use per day
    :type native_use_per_day: float
    :param native_use_unit:
    :type native_use_unit: ~energycap.sdk.models.UnitChild
    :param native_demand: Native demand
    :type native_demand: float
    :param native_demand_unit:
    :type native_demand_unit: ~energycap.sdk.models.UnitChild
    :param native_billed_demand: Native billed demand
    :type native_billed_demand: float
    :param native_billed_demand_unit:
    :type native_billed_demand_unit: ~energycap.sdk.models.UnitChild
    :param native_actual_demand: Native actual demand
    :type native_actual_demand: float
    :param native_actual_demand_unit:
    :type native_actual_demand_unit: ~energycap.sdk.models.UnitChild
    :param common_use: Common use
    :type common_use: float
    :param common_use_per_day: Common use per day
    :type common_use_per_day: float
    :param common_use_unit:
    :type common_use_unit: ~energycap.sdk.models.UnitChild
    :param common_demand: Common demand
    :type common_demand: float
    :param common_demand_unit:
    :type common_demand_unit: ~energycap.sdk.models.UnitChild
    :param common_billed_demand: Common billed demand
    :type common_billed_demand: float
    :param common_billed_demand_unit:
    :type common_billed_demand_unit: ~energycap.sdk.models.UnitChild
    :param common_actual_demand: Common actual demand
    :type common_actual_demand: float
    :param common_actual_demand_unit:
    :type common_actual_demand_unit: ~energycap.sdk.models.UnitChild
    :param direct_cost: Direct cost
    :type direct_cost: float
    :param direct_cost_per_day: Direct cost per day
    :type direct_cost_per_day: float
    :param proportional_cost: Proportional cost
    :type proportional_cost: float
    :param proportional_cost_per_day: Proportional cost per day
    :type proportional_cost_per_day: float
    :param cost_unit:
    :type cost_unit: ~energycap.sdk.models.UnitChild
    """

    _attribute_map = {
        'bill_id': {'key': 'billId', 'type': 'int'},
        'billing_period': {'key': 'billingPeriod', 'type': 'int'},
        'begin_date': {'key': 'beginDate', 'type': 'iso-8601'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
        'days': {'key': 'days', 'type': 'int'},
        'account': {'key': 'account', 'type': 'AccountChild'},
        'meter': {'key': 'meter', 'type': 'MeterChild'},
        'global_use': {'key': 'globalUse', 'type': 'float'},
        'global_use_per_day': {'key': 'globalUsePerDay', 'type': 'float'},
        'global_use_unit': {'key': 'globalUseUnit', 'type': 'UnitChild'},
        'native_use': {'key': 'nativeUse', 'type': 'float'},
        'native_use_per_day': {'key': 'nativeUsePerDay', 'type': 'float'},
        'native_use_unit': {'key': 'nativeUseUnit', 'type': 'UnitChild'},
        'native_demand': {'key': 'nativeDemand', 'type': 'float'},
        'native_demand_unit': {'key': 'nativeDemandUnit', 'type': 'UnitChild'},
        'native_billed_demand': {'key': 'nativeBilledDemand', 'type': 'float'},
        'native_billed_demand_unit': {'key': 'nativeBilledDemandUnit', 'type': 'UnitChild'},
        'native_actual_demand': {'key': 'nativeActualDemand', 'type': 'float'},
        'native_actual_demand_unit': {'key': 'nativeActualDemandUnit', 'type': 'UnitChild'},
        'common_use': {'key': 'commonUse', 'type': 'float'},
        'common_use_per_day': {'key': 'commonUsePerDay', 'type': 'float'},
        'common_use_unit': {'key': 'commonUseUnit', 'type': 'UnitChild'},
        'common_demand': {'key': 'commonDemand', 'type': 'float'},
        'common_demand_unit': {'key': 'commonDemandUnit', 'type': 'UnitChild'},
        'common_billed_demand': {'key': 'commonBilledDemand', 'type': 'float'},
        'common_billed_demand_unit': {'key': 'commonBilledDemandUnit', 'type': 'UnitChild'},
        'common_actual_demand': {'key': 'commonActualDemand', 'type': 'float'},
        'common_actual_demand_unit': {'key': 'commonActualDemandUnit', 'type': 'UnitChild'},
        'direct_cost': {'key': 'directCost', 'type': 'float'},
        'direct_cost_per_day': {'key': 'directCostPerDay', 'type': 'float'},
        'proportional_cost': {'key': 'proportionalCost', 'type': 'float'},
        'proportional_cost_per_day': {'key': 'proportionalCostPerDay', 'type': 'float'},
        'cost_unit': {'key': 'costUnit', 'type': 'UnitChild'},
    }

    def __init__(self, bill_id=None, billing_period=None, begin_date=None, end_date=None, days=None, account=None, meter=None, global_use=None, global_use_per_day=None, global_use_unit=None, native_use=None, native_use_per_day=None, native_use_unit=None, native_demand=None, native_demand_unit=None, native_billed_demand=None, native_billed_demand_unit=None, native_actual_demand=None, native_actual_demand_unit=None, common_use=None, common_use_per_day=None, common_use_unit=None, common_demand=None, common_demand_unit=None, common_billed_demand=None, common_billed_demand_unit=None, common_actual_demand=None, common_actual_demand_unit=None, direct_cost=None, direct_cost_per_day=None, proportional_cost=None, proportional_cost_per_day=None, cost_unit=None):
        super(BillAccountMeterResponse, self).__init__()
        self.bill_id = bill_id
        self.billing_period = billing_period
        self.begin_date = begin_date
        self.end_date = end_date
        self.days = days
        self.account = account
        self.meter = meter
        self.global_use = global_use
        self.global_use_per_day = global_use_per_day
        self.global_use_unit = global_use_unit
        self.native_use = native_use
        self.native_use_per_day = native_use_per_day
        self.native_use_unit = native_use_unit
        self.native_demand = native_demand
        self.native_demand_unit = native_demand_unit
        self.native_billed_demand = native_billed_demand
        self.native_billed_demand_unit = native_billed_demand_unit
        self.native_actual_demand = native_actual_demand
        self.native_actual_demand_unit = native_actual_demand_unit
        self.common_use = common_use
        self.common_use_per_day = common_use_per_day
        self.common_use_unit = common_use_unit
        self.common_demand = common_demand
        self.common_demand_unit = common_demand_unit
        self.common_billed_demand = common_billed_demand
        self.common_billed_demand_unit = common_billed_demand_unit
        self.common_actual_demand = common_actual_demand
        self.common_actual_demand_unit = common_actual_demand_unit
        self.direct_cost = direct_cost
        self.direct_cost_per_day = direct_cost_per_day
        self.proportional_cost = proportional_cost
        self.proportional_cost_per_day = proportional_cost_per_day
        self.cost_unit = cost_unit



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReportChild(Model):
    """ReportChild.

    :param version:
    :type version: str
    :param report_id:
    :type report_id: int
    :param report_code:
    :type report_code: str
    :param report_info:
    :type report_info: str
    :param report_type:
    :type report_type: ~energycap.sdk.models.ReportType
    :param description:
    :type description: str
    :param is_landscape:
    :type is_landscape: bool
    :param last_updated:
    :type last_updated: datetime
    :param tags:
    :type tags: list[~energycap.sdk.models.TagChild]
    :param export_formats:
    :type export_formats: list[~energycap.sdk.models.ExportFormatChild]
    """

    _attribute_map = {
        'version': {'key': 'version', 'type': 'str'},
        'report_id': {'key': 'reportId', 'type': 'int'},
        'report_code': {'key': 'reportCode', 'type': 'str'},
        'report_info': {'key': 'reportInfo', 'type': 'str'},
        'report_type': {'key': 'reportType', 'type': 'ReportType'},
        'description': {'key': 'description', 'type': 'str'},
        'is_landscape': {'key': 'isLandscape', 'type': 'bool'},
        'last_updated': {'key': 'lastUpdated', 'type': 'iso-8601'},
        'tags': {'key': 'tags', 'type': '[TagChild]'},
        'export_formats': {'key': 'exportFormats', 'type': '[ExportFormatChild]'},
    }

    def __init__(self, version=None, report_id=None, report_code=None, report_info=None, report_type=None, description=None, is_landscape=None, last_updated=None, tags=None, export_formats=None):
        super(ReportChild, self).__init__()
        self.version = version
        self.report_id = report_id
        self.report_code = report_code
        self.report_info = report_info
        self.report_type = report_type
        self.description = description
        self.is_landscape = is_landscape
        self.last_updated = last_updated
        self.tags = tags
        self.export_formats = export_formats



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarPlaceHierarchyResponse(Model):
    """EnergyStarPlaceHierarchyResponse.

    :param place:
    :type place: ~energycap.sdk.models.PlaceChild
    :param place_size:
    :type place_size: ~energycap.sdk.models.PlaceSizeChild
    :param metrics: ENERGY STAR score data for the place
     If there are multiple places returned in the response, will be the most
     recent score
    :type metrics: list[~energycap.sdk.models.EnergyStarPlaceMetricsResponse]
    """

    _attribute_map = {
        'place': {'key': 'place', 'type': 'PlaceChild'},
        'place_size': {'key': 'placeSize', 'type': 'PlaceSizeChild'},
        'metrics': {'key': 'metrics', 'type': '[EnergyStarPlaceMetricsResponse]'},
    }

    def __init__(self, place=None, place_size=None, metrics=None):
        super(EnergyStarPlaceHierarchyResponse, self).__init__()
        self.place = place
        self.place_size = place_size
        self.metrics = metrics



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ListCopy(Model):
    """ListCopy.

    :param list_info: The list name <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 32 characters</span>
    :type list_info: str
    :param list_description: The list description <span
     class='property-internal'>Must be between 0 and 255 characters</span>
    :type list_description: str
    """

    _validation = {
        'list_info': {'required': True, 'max_length': 32, 'min_length': 0},
        'list_description': {'max_length': 255, 'min_length': 0},
    }

    _attribute_map = {
        'list_info': {'key': 'listInfo', 'type': 'str'},
        'list_description': {'key': 'listDescription', 'type': 'str'},
    }

    def __init__(self, list_info, list_description=None):
        super(ListCopy, self).__init__()
        self.list_info = list_info
        self.list_description = list_description



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillHeaderUpdate(Model):
    """Bill header values to update.

    :param begin_date:
    :type begin_date: ~energycap.sdk.models.BillHeaderUpdateBeginDateChild
    :param end_date:
    :type end_date: ~energycap.sdk.models.BillHeaderUpdateEndDateChild
    :param due_date:
    :type due_date: ~energycap.sdk.models.BillHeaderUpdateDueDateChild
    :param statement_date:
    :type statement_date:
     ~energycap.sdk.models.BillHeaderUpdateStatementDateChild
    :param control_code:
    :type control_code: ~energycap.sdk.models.BillHeaderUpdateControlCodeChild
    :param invoice_number:
    :type invoice_number:
     ~energycap.sdk.models.BillHeaderUpdateInvoiceNumberChild
    :param account_period:
    :type account_period:
     ~energycap.sdk.models.BillHeaderUpdateAccountPeriodChild
    :param billing_period:
    :type billing_period:
     ~energycap.sdk.models.BillHeaderUpdateBillingPeriodChild
    :param estimated:
    :type estimated: ~energycap.sdk.models.BillHeaderUpdateEstimatedChild
    """

    _validation = {
        'begin_date': {'required': True},
        'end_date': {'required': True},
        'due_date': {'required': True},
        'statement_date': {'required': True},
        'control_code': {'required': True},
        'invoice_number': {'required': True},
        'account_period': {'required': True},
        'billing_period': {'required': True},
        'estimated': {'required': True},
    }

    _attribute_map = {
        'begin_date': {'key': 'beginDate', 'type': 'BillHeaderUpdateBeginDateChild'},
        'end_date': {'key': 'endDate', 'type': 'BillHeaderUpdateEndDateChild'},
        'due_date': {'key': 'dueDate', 'type': 'BillHeaderUpdateDueDateChild'},
        'statement_date': {'key': 'statementDate', 'type': 'BillHeaderUpdateStatementDateChild'},
        'control_code': {'key': 'controlCode', 'type': 'BillHeaderUpdateControlCodeChild'},
        'invoice_number': {'key': 'invoiceNumber', 'type': 'BillHeaderUpdateInvoiceNumberChild'},
        'account_period': {'key': 'accountPeriod', 'type': 'BillHeaderUpdateAccountPeriodChild'},
        'billing_period': {'key': 'billingPeriod', 'type': 'BillHeaderUpdateBillingPeriodChild'},
        'estimated': {'key': 'estimated', 'type': 'BillHeaderUpdateEstimatedChild'},
    }

    def __init__(self, begin_date, end_date, due_date, statement_date, control_code, invoice_number, account_period, billing_period, estimated):
        super(BillHeaderUpdate, self).__init__()
        self.begin_date = begin_date
        self.end_date = end_date
        self.due_date = due_date
        self.statement_date = statement_date
        self.control_code = control_code
        self.invoice_number = invoice_number
        self.account_period = account_period
        self.billing_period = billing_period
        self.estimated = estimated



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class FailedReadingResponse(Model):
    """FailedReadingResponse.

    :param channel_id:
    :type channel_id: int
    :param channel_import_id:
    :type channel_import_id: str
    :param meter_import_id:
    :type meter_import_id: str
    :param observation_type_code:
    :type observation_type_code: str
    :param unit_code:
    :type unit_code: str
    :param channel_interval_in_seconds:
    :type channel_interval_in_seconds: int
    :param readings:
    :type readings: list[~energycap.sdk.models.FailedReadings]
    :param error:
    :type error: str
    """

    _attribute_map = {
        'channel_id': {'key': 'channelId', 'type': 'int'},
        'channel_import_id': {'key': 'channelImportId', 'type': 'str'},
        'meter_import_id': {'key': 'meterImportId', 'type': 'str'},
        'observation_type_code': {'key': 'observationTypeCode', 'type': 'str'},
        'unit_code': {'key': 'unitCode', 'type': 'str'},
        'channel_interval_in_seconds': {'key': 'channelIntervalInSeconds', 'type': 'int'},
        'readings': {'key': 'readings', 'type': '[FailedReadings]'},
        'error': {'key': 'error', 'type': 'str'},
    }

    def __init__(self, channel_id=None, channel_import_id=None, meter_import_id=None, observation_type_code=None, unit_code=None, channel_interval_in_seconds=None, readings=None, error=None):
        super(FailedReadingResponse, self).__init__()
        self.channel_id = channel_id
        self.channel_import_id = channel_import_id
        self.meter_import_id = meter_import_id
        self.observation_type_code = observation_type_code
        self.unit_code = unit_code
        self.channel_interval_in_seconds = channel_interval_in_seconds
        self.readings = readings
        self.error = error



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarCommodityMappingChild(Model):
    """EnergyStarCommodityMappingChild.

    :param pm_unit_code: The unit code in Portfolio Manager
    :type pm_unit_code: str
    :param supported_pm_commodities: The commodity code in Portfolio Manager
    :type supported_pm_commodities: list[str]
    """

    _attribute_map = {
        'pm_unit_code': {'key': 'pmUnitCode', 'type': 'str'},
        'supported_pm_commodities': {'key': 'supportedPmCommodities', 'type': '[str]'},
    }

    def __init__(self, pm_unit_code=None, supported_pm_commodities=None):
        super(EnergyStarCommodityMappingChild, self).__init__()
        self.pm_unit_code = pm_unit_code
        self.supported_pm_commodities = supported_pm_commodities



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReportEmail(Model):
    """ReportEmail.

    :param email_message_id: Unique identifier for the email sent to the
     recipient
     Will be null if the report email couldn't be sent
    :type email_message_id: str
    :param subject: Email subject
     Will be null if the report email couldn't be sent
    :type subject: str
    :param recipient: Email recipient
     Will be a list of all intended email addresses if the report email
     couldn't be sent
    :type recipient: str
    :param specific_report_id: Unique identifier of the specific instance of
     the base report
    :type specific_report_id: int
    :param specific_report_info: Specific report name
    :type specific_report_info: str
    :param specific_report_code: Specific report code
    :type specific_report_code: str
    :param base_report_id: Unique identifier of the base report
    :type base_report_id: int
    :param base_report_code: Base report code
    :type base_report_code: str
    :param base_report_info: Base report name
    :type base_report_info: str
    """

    _attribute_map = {
        'email_message_id': {'key': 'emailMessageId', 'type': 'str'},
        'subject': {'key': 'subject', 'type': 'str'},
        'recipient': {'key': 'recipient', 'type': 'str'},
        'specific_report_id': {'key': 'specificReportId', 'type': 'int'},
        'specific_report_info': {'key': 'specificReportInfo', 'type': 'str'},
        'specific_report_code': {'key': 'specificReportCode', 'type': 'str'},
        'base_report_id': {'key': 'baseReportId', 'type': 'int'},
        'base_report_code': {'key': 'baseReportCode', 'type': 'str'},
        'base_report_info': {'key': 'baseReportInfo', 'type': 'str'},
    }

    def __init__(self, email_message_id=None, subject=None, recipient=None, specific_report_id=None, specific_report_info=None, specific_report_code=None, base_report_id=None, base_report_code=None, base_report_info=None):
        super(ReportEmail, self).__init__()
        self.email_message_id = email_message_id
        self.subject = subject
        self.recipient = recipient
        self.specific_report_id = specific_report_id
        self.specific_report_info = specific_report_info
        self.specific_report_code = specific_report_code
        self.base_report_id = base_report_id
        self.base_report_code = base_report_code
        self.base_report_info = base_report_info
